--
-- Datenbank: `terra`
-- Aus der Mondial-Datenbank erzeugt und bearbeitet von T. Mohr, 2008
-- Für SQLite bearbeitet von C. Pothmann, 2020
-- Quelle (Terra): https://inf-schule.de/information/datenbanksysteme/terra
-- Lizenz: CC BY-SA 4.0
-- Quelle (Mondial): https://www.dbis.informatik.uni-goettingen.de/Mondial/
-- Lizenz: CC BY 3.0
--

-- Tabellen --

CREATE TABLE `Kontinent` (
  `KNR` varchar(2) NOT NULL,
  `Name` varchar(15) default NULL,
  `Flaeche` double(53,0) default NULL,
  PRIMARY KEY  (`KNR`)
);

CREATE TABLE `Land` (
  `LNR` varchar(4) NOT NULL,
  `Name` varchar(50) default NULL,
  `KNR` varchar(3) default NULL,
  `Einwohner` double(20,2) default NULL,
  `Flaeche` double(53,0) default NULL,
  `HauptONR` varchar(6) default NULL,
  PRIMARY KEY  (`LNR`)
);

CREATE TABLE `Ort` (
  `ONR` varchar(6) NOT NULL,
  `Name` varchar(25) default NULL,
  `LNR` varchar(4) default NULL,
  `Landesteil` varchar(30) default NULL,
  `Einwohner` double(53,0) default NULL,
  `Breite` double(53,0) default NULL,
  `Laenge` double(53,0) default NULL,
  PRIMARY KEY  (`ONR`)
);

CREATE TABLE `Sprache` (
  `SNR` varchar(3) NOT NULL,
  `Name` varchar(50) NOT NULL,
  PRIMARY KEY  (`SNR`)
);

CREATE TABLE `gesprochen` (
  `SNR` varchar(3) NOT NULL,
  `LNR` varchar(4) NOT NULL,
  `Anteil` tinyint(4) default NULL,
  PRIMARY KEY  (`SNR`,`LNR`)
);

-- Daten --

INSERT INTO `Kontinent` (`KNR`, `Name`, `Flaeche`) VALUES
('AF', 'Afrika', 31),
('SA', 'Südamerika', 18),
('AS', 'Asien', 44),
('AU', 'Australien', 9),
('EU', 'Europa', 10),
('NA', 'Nordamerika', 24);

INSERT INTO `Land` (`LNR`, `Name`, `KNR`, `Einwohner`, `Flaeche`, `HauptONR`) VALUES
('A', 'Österreich', 'EU', 8.13, 83845, 'WIEN'),
('AF', 'Afghanistan', 'AS', 25.84, 647497, 'KABUL'),
('AL', 'Albanien', 'EU', 3.49, 28748, 'TIRANA'),
('AN', 'Andorra', 'EU', 0.07, 468, 'ANDORR'),
('AC', 'Antigua und Barbuda', 'NA', 0.07, 442, 'SAINTJ'),
('AUS', 'Australien', 'AU', 19.17, 7686420, 'CANBER'),
('B', 'Belgien', 'EU', 10.24, 30510, 'BRUESS'),
('BB', 'Barbados', 'NA', 0.27, 431, 'BRIDGE'),
('UV', 'Burkina Faso', 'AF', 11.95, 274000, 'OUAGAD'),
('BG', 'Bulgarien', 'EU', 8.89, 110994, 'SOFIA'),
('BH', 'Belize', 'NA', 0.17, 249183, 'BELMOP'),
('BHU', 'Bhutan', 'AS', 1.45, 47000, 'THIMBU'),
('BIH', 'Bosnien-Herzegowina', 'EU', 3.78, 51129, 'SARAJE'),
('BOL', 'Bolivien', 'SA', 6.55, 109858, 'SUCRE'),
('BR', 'Brasilien', 'SA', 141.45, 851196, 'BRASIL'),
('BA', 'Bahrein', 'AS', 0.63, 620, 'MANAMA'),
('BRU', 'Brunei', 'AS', 0.23, 5765, 'BANDAR'),
('BF', 'Bahamas', 'AF', 0.29, 13940, 'NASSAU'),
('BU', 'Burundi', 'AF', 3.40, 28000, 'BUJUMB'),
('BUR', 'Birma', 'AS', 40.48, 678528, 'RANGOO'),
('C', 'Kuba', 'NA', 10.30, 114524, 'HAVANN'),
('CAM', 'Kamerun', 'AF', 10.90, 475000, 'JAUNDE'),
('CDN', 'Kanada', 'NA', 25.61, 9976000, 'OTTAWA'),
('CH', 'Schweiz', 'EU', 6.97, 39988, 'BERN'),
('CI', 'Elfenbeinküste', 'AF', 10.20, 322000, 'ABIDJA'),
('CL', 'Sri Lanka', 'AS', 19.24, 65610, 'COLOMB'),
('CO', 'Kolumbien', 'SA', 29.73, 113891, 'BOGOTA'),
('CR', 'Costa Rica', 'NA', 2.67, 50700, 'SAN_JO'),
('CY', 'Zypern', 'EU', 0.73, 9251, 'NICOSI'),
('CZ', 'Tschechische Republik', 'EU', 10.27, 127869, 'PRAG'),
('D', 'Deutschland', 'EU', 82.26, 356973, 'BERLIN'),
('DARS', 'Sahara', 'AF', 0.20, 266000, 'EL_ALA'),
('DK', 'Dänemark', 'EU', 5.17, 43094, 'KOPENH'),
('DOM', 'Dominikanische Republik', 'NA', 6.72, 48734, 'SANTO_'),
('AG', 'Algerien', 'AF', 31.19, 2381000, 'ALGIER'),
('E', 'Spanien', 'EU', 39.48, 504782, 'MADRID'),
('EAK', 'Kenia', 'AF', 22.90, 583000, 'NAIROB'),
('EAS', 'Sudan', 'AF', 22.20, 2505000, 'KHARTU'),
('EAT', 'Tansania', 'AF', 22.50, 945000, 'DARESS'),
('EAU', 'Uganda', 'AF', 16.00, 236000, 'KAMPAL'),
('EC', 'Ecuador', 'SA', 9.65, 283561, 'QUITO'),
('ES', 'El Salvador', 'NA', 5.01, 21041, 'SAN_SA'),
('EST', 'Estland', 'EU', 1.55, 45227, 'TALLIN'),
('ET', 'Ägypten', 'AF', 68.36, 1001450, 'KAIRO'),
('ETH', 'Äthiopien', 'AF', 64.12, 1222000, 'ADDIS_'),
('F', 'Frankreich', 'EU', 61.87, 543965, 'PARIS'),
('FIJI', 'Fidschi', 'AU', 0.71, 18272, 'SUVA'),
('FL', 'Liechtenstein', 'EU', 0.03, 160, 'LIECHT'),
('FSM', 'Mikronesien', 'AU', 0.11, 720, 'KOLONI'),
('GAB', 'Gabun', 'AF', 1.20, 268000, 'LIBREV'),
('GB', 'Großbritannien', 'EU', 57.92, 241752, 'LONDON'),
('GCA', 'Guatemala', 'NA', 8.43, 108889, 'CIUDAD'),
('GH', 'Ghana', 'AF', 12.20, 239000, 'ACCRA'),
('GR', 'Griechenland', 'EU', 10.37, 131957, 'ATHEN'),
('GUB', 'Guinea-Bissau', 'AF', 0.90, 36000, 'BISSAU'),
('GUI', 'Guinea', 'AF', 6.30, 246000, 'CONAKR'),
('GUY', 'Guyana', 'SA', 0.97, 214969, 'GEORGE'),
('H', 'Ungarn', 'EU', 65.67, 93030, 'BUDAPE'),
('HON', 'Honduras', 'NA', 4.51, 112088, 'TEGUCI'),
('HR', 'Kroatien', 'EU', 4.51, 56538, 'ZAGREB'),
('I', 'Italien', 'EU', 57.12, 301302, 'ROM'),
('IL', 'Israel', 'AS', 4.37, 20770, 'JERUSA'),
('IND', 'Indien', 'AS', 761.00, 3287590, 'DELHI'),
('IR', 'Iran', 'AS', 41.07, 1648195, 'TEHERA'),
('IRL', 'Irland', 'EU', 3.53, 70285, 'DUBLIN'),
('IRQ', 'Irak', 'AS', 16.45, 438446, 'BAGDAD'),
('IS', 'Island', 'EU', 0.26, 103000, 'REYKJA'),
('J', 'Japan', 'AS', 120.05, 372313, 'TOKYO'),
('JA', 'Jamaika', 'NA', 2.37, 10991, 'KINGSJ'),
('JB', 'Bophuthatswana', 'AF', 1.70, 44000, 'MMABAT'),
('JEM', 'Jemen', 'AS', 9.27, 195000, 'SANA'),
('JOR', 'Jordanien', 'AS', 3.66, 97740, 'AMMAN'),
('KAP', 'Kap Verde', 'AF', 0.33, 4000, 'PRAIA'),
('KIR', 'Kiribati', 'AU', 0.06, 886, 'BAIRIK'),
('KOM', 'Komoren', 'AF', 0.44, 1900, 'MORONI'),
('KSA', 'Saudi-Arabien', 'AS', 13.61, 2149690, 'ER_RIA'),
('KT', 'Kuweit', 'AS', 1.87, 17818, 'KUWAIT'),
('L', 'Luxemburg', 'EU', 0.40, 2586, 'LUXEMB'),
('LAO', 'Laos', 'AS', 4.22, 236800, 'VIENTI'),
('LAR', 'Libyen', 'AF', 3.70, 1760000, 'TRIPOL'),
('LB', 'Liberia', 'AF', 2.40, 111000, 'MONROV'),
('LS', 'Lesotho', 'AF', 1.60, 30000, 'MASERU'),
('LT', 'Litauen', 'EU', 3.71, 65300, 'VILNIU'),
('LV', 'Lettland', 'EU', 2.61, 64589, 'RIGA'),
('M', 'Malta', 'EU', 0.36, 316, 'VALLET'),
('MA', 'Marokko', 'AF', 22.50, 459000, 'RABAT'),
('MY', 'Malaysia', 'AS', 21.79, 329750, 'KUALAL'),
('MAR', 'Marshallinseln', 'AU', 0.04, 181, 'ULIGA'),
('MC', 'Monaco', 'EU', 0.03, 2, 'MONACO'),
('MD', 'Moldawien', 'EU', 4.41, 33700, 'CHISIN'),
('MEX', 'Mexiko', 'NA', 100.35, 1972547, 'MEXICO'),
('MK', 'Mazedonien', 'EU', 2.08, 25713, 'SKOPJE'),
('MON', 'Mongolische Volksrepublik', 'AS', 1.94, 1565000, 'ULAN_B'),
('MOS', 'Mosambique', 'AF', 14.60, 799000, 'MAPUTO'),
('MS', 'Mauritius', 'AF', 1.40, 2000, 'PORT_L'),
('MW', 'Malawi', 'AF', 13.01, 118480, 'LILONG'),
('N', 'Norwegen', 'EU', 4.30, 323877, 'OSLO'),
('NAU', 'Nauru', 'AU', 0.01, 21, 'YAREN'),
('NEP', 'Nepal', 'AS', 17.13, 140797, 'KATMAN'),
('NIC', 'Nicaragua', 'NA', 3.38, 130000, 'MANAGU'),
('NL', 'Niederlande', 'EU', 15.28, 41865, 'AMSTER'),
('NZ', 'Neuseeland', 'AU', 3.28, 269063, 'WELLIN'),
('OMA', 'Oman', 'AS', 2.53, 212457, 'MASKAT'),
('P', 'Portugal', 'EU', 9.84, 92389, 'LISSAB'),
('PA', 'Panama', 'NA', 2.27, 75650, 'CIUPAN'),
('PAK', 'Pakistan', 'AS', 102.24, 803943, 'ISLAMA'),
('PAL', 'Palau', 'AU', 0.01, 458, 'KOROR'),
('PE', 'Peru', 'SA', 27.01, 128521, 'LIMA'),
('PI', 'Philippinen', 'AS', 56.98, 300000, 'MANILA'),
('PL', 'Polen', 'EU', 38.65, 312683, 'WARSCH'),
('PNG', 'Papua-Neuguinea', 'AU', 3.40, 461691, 'PORT_M'),
('PY', 'Paraguay', 'SA', 3.92, 406752, 'ASUNCI'),
('Q', 'Quatar', 'AS', 0.74, 10437, 'DOHA'),
('RA', 'Argentinien', 'SA', 36.96, 277688, 'BUENOS'),
('RB', 'Botswana', 'AF', 1.20, 600000, 'GABARO'),
('RCA', 'Zentralafrikanische Republik', 'AF', 2.70, 623000, 'BANGUI'),
('RCB', 'Kongo', 'AF', 1.80, 342000, 'BRAZZA'),
('RCH', 'Chile', 'SA', 12.54, 756945, 'SANTIA'),
('RD', 'Djibuti', 'AF', 0.50, 22000, 'DJIBUT'),
('RGE', 'Äquatorialguinea', 'AF', 0.47, 28000, 'MALABO'),
('RH', 'Haiti', 'NA', 5.44, 27750, 'PORT_A'),
('RI', 'Indonesien', 'AS', 170.53, 1919443, 'JAKART'),
('RIM', 'Mauretanien', 'AF', 2.00, 1031000, 'NUAKSC'),
('RL', 'Libanon', 'AS', 2.71, 10400, 'BEIRUT'),
('RM', 'Madagaskar', 'AF', 10.30, 587000, 'TANANA'),
('RMAL', 'Malediven', 'AS', 0.19, 298, 'MALE'),
('RMM', 'Mali', 'AF', 8.70, 1240000, 'BAMAKO'),
('RN', 'Niger', 'AF', 10.06, 1267000, 'NIAMEY'),
('RO', 'Rumänien', 'EU', 22.76, 237500, 'BUKARE'),
('ROC', 'Taiwan', 'AS', 19.14, 36188, 'TAIPEH'),
('ROK', 'Korea', 'AS', 42.03, 98484, 'SEOUL'),
('AO', 'Angola', 'AF', 10.15, 1246000, 'LUANDA'),
('RPB', 'Benin', 'AF', 6.40, 112620, 'PORTON'),
('RSA', 'Südafrika', 'AF', 22.80, 1123000, 'PRETOR'),
('RSM', 'San Marino', 'EU', 0.03, 60, 'SAN_MA'),
('RUS', 'Russland', 'AS', 146.00, 17075400, 'MOSKAU'),
('RWA', 'Rwanda', 'AF', 6.30, 26000, 'KIGALI'),
('S', 'Schweden', 'EU', 8.69, 449964, 'STOCKH'),
('SAL', 'Salomonen', 'AU', 0.28, 28446, 'HONIAR'),
('SAO', 'Sao Tome und Principe', 'AF', 0.09, 859, 'SAO_TO'),
('SCN', 'Saint Kitts u Nevis', 'NA', 0.06, 267, 'BASSET'),
('SCV', 'Vatikanstadt', 'EU', 0.00, 1, 'VATIKA'),
('SD', 'Swasiland', 'AF', 0.67, 17000, 'MBABAN'),
('SF', 'Finnland', 'EU', 5.06, 338144, 'HELSIN'),
('SGP', 'Singapur', 'AS', 2.61, 618, 'SINGAP'),
('SK', 'Slowakei', 'EU', 5.41, 49036, 'BRATIS'),
('SLO', 'Slowenien', 'EU', 1.94, 20253, 'LJUBLJ'),
('SME', 'Surinam', 'SA', 0.38, 163265, 'PARAMA'),
('SN', 'Senegal', 'AF', 6.60, 196000, 'DAKAR'),
('SP', 'Somalia', 'AF', 4.80, 638000, 'MOGADI'),
('SWA', 'Namibia', 'AF', 1.60, 823000, 'WINDHU'),
('SY', 'Seychellen', 'AF', 0.08, 455, 'VICTOR'),
('SYR', 'Syrien', 'AS', 12.20, 182000, 'DAMASK'),
('TCH', 'Tschad', 'AF', 5.10, 1284000, 'NDJAM'),
('TG', 'Togo', 'AF', 3.10, 56000, 'LOME'),
('THA', 'Thailand', 'AS', 61.23, 513115, 'BANGKO'),
('TN', 'Tunesien', 'AF', 7.50, 164000, 'TUNIS'),
('TON', 'Tonga', 'AU', 0.11, 699, 'NUKUAL'),
('TR', 'Türkei', 'AS', 59.60, 779452, 'ANKARA'),
('TT', 'Trinidad und Tobago', 'SA', 1.20, 5128, 'PORT_O'),
('TUV', 'Tuvalu', 'AU', 0.01, 24, 'VEIAKU'),
('U', 'Uruguay', 'SA', 2.98, 177508, 'MONTEV'),
('UA', 'Ukraine', 'EU', 51.55, 603700, 'KIEW'),
('UAE', 'Vereinigte Arabische Emirate', 'AS', 1.38, 83600, 'ABU_DH'),
('USA', 'Vereinigte Staaten von Amerika', 'NA', 242.08, 9363000, 'WASHIN'),
('V', 'Venda', 'AF', 0.50, 7400, 'THOHOY'),
('VAN', 'Vanuatu', 'AU', 0.14, 14763, 'PORT_V'),
('VN', 'Vietnam', 'AS', 78.77, 332556, 'HANOI'),
('VRC', 'China', 'AS', 1321.00, 9572419, 'PEKING'),
('VRK', 'Kambodscha', 'AS', 7.28, 181035, 'PHNOMP'),
('WAG', 'Gambia', 'AF', 0.69, 11300, 'BANJUL'),
('WAL', 'Sierra Leone', 'AF', 3.70, 72000, 'FREETO'),
('WAN', 'Nigeria', 'AF', 98.50, 924000, 'LAGOS'),
('WD', 'Dominica', 'NA', 0.08, 751, 'ROSEAU'),
('WG', 'Grenada', 'NA', 0.11, 344, 'SAINTG'),
('WL', 'Saint Lucia', 'NA', 0.14, 616, 'CASTRI'),
('WS', 'Westsamoa', 'AU', 0.16, 2842, 'APIA'),
('WV', 'Saint Vincent', 'NA', 0.12, 389, 'KINGST'),
('X', 'Transkei', 'AF', 2.70, 39000, 'UMTATA'),
('YU', 'Jugoslawien', 'EU', 10.57, 102173, 'BELGRA'),
('YV', 'Venezuela', 'SA', 23.54, 912050, 'CARACA'),
('Z', 'Sambia', 'AF', 11.26, 752614, 'LUSAKA'),
('ZRE', 'Zaire', 'AF', 30.90, 2345000, 'KINSHA'),
('ZW', 'Simbabwe', 'AF', 8.40, 391000, 'SALISB'),
('AM', 'Armenien', 'AS', 3.34, 29800, 'ERIWAN'),
('BD', 'Bangladesch', 'AS', 129.19, 144000, 'DHAKA'),
('BY', 'Weißrussland', 'EU', 10.37, 207600, 'MINSK'),
('GE', 'Georgien', 'AS', 4.65, 69700, 'TBILIS'),
('UZB', 'Usbekistan ', 'AS', 26.48, 447400, 'TASCHK'),
('AZ', 'Aserbaidschan', 'AS', 8.46, 86600, 'BAKU'),
('KAS', 'Kasachstan', 'AS', 15.23, 2717300, 'ALMA-A'),
('TM', 'Turkmenistan', 'AS', 5.00, 488000, 'ASGABA'),
('KGS', 'Kirgisistan', 'AS', 5.08, 198500, 'BISCHK'),
('TAD', 'Tadschikistan', 'AS', 7.32, 143100, 'DUSHAN');


INSERT INTO `Ort` (`ONR`, `Name`, `LNR`, `Landesteil`, `Einwohner`, `Breite`, `Laenge`) VALUES
('AACHEN', 'Aachen', 'D', 'Nordrhein-Westfalen', 247792, 51, 6),
('AALBOR', 'Aalborg', 'DK', NULL, 158000, 57, 10),
('AARHUS', 'Aarhus', 'DK', NULL, 614000, 56, 10),
('ABADAN', 'Abadan', 'IR', 'Khuzestan', 310000, 30, 48),
('ABIDJA', 'Abidjan', 'CI', NULL, 800000, 5, -4),
('ABU_DH', 'Abu Dhabi', 'UAE', 'Vereinigte Arabische Emirate', 928000, 24, 54),
('ACCRA', 'Accra', 'GH', NULL, 949000, 5, 0),
('ADDIS_', 'Addis Abeba', 'ETH', NULL, 2200000, 9, 38),
('ADELAI', 'Adelaide', 'AUS', NULL, 1080000, -35, 138),
('ADEN', 'Aden', 'JEM', NULL, 550000, 13, 50),
('AGARTA', 'Agartala', 'IND', 'Tripura', 158000, 23, 91),
('AGUASC', 'Aguascalientes', 'MEX', 'Aguascalientes', 888000, 21, -102),
('AHWAZ', 'Ahwaz', 'IR', 'Khuzestan', 334399, 31, 48),
('AIZAWL', 'Aizawl', 'IND', 'Mizoram', NULL, 23, 92),
('AJACCI', 'Ajaccio', 'F', 'Corse', 59300, 41, 8),
('AKUREY', 'Akureyri', 'IS', NULL, 14800, 65, 18),
('ALBANY', 'Albany', 'USA', 'New York', 101000, 42, -74),
('ALDERN', 'Alderney', 'GB', 'Alderney', 2000, 49, -2),
('ALEPPO', 'Aleppo', 'SYR', NULL, 1540000, 36, 37),
('ALEXAN', 'Alexandria', 'ET', NULL, 3430000, 31, 30),
('ALGIER', 'Algier', 'AG', 'Algier', 2170000, 36, 4),
('ALMA-A', 'Alma-Ata', 'RUS', NULL, 1100000, 43, 77),
('AMIENS', 'Amiens', 'F', 'Picardie', 136000, 50, 2),
('AMMAN', 'Amman', 'JOR', NULL, 965000, 32, 36),
('AMSTER', 'Amsterdam', 'NL', 'Noord-Holland', 724000, 52, 5),
('ANCONA', 'Ancona', 'I', 'Marhen', 439000, 43, 13),
('ANDORR', 'Andorra la Vella', 'AN', NULL, 22000, 42, 1),
('ANKARA', 'Ankara', 'TR', 'Tuerkei', 2560000, 40, 32),
('ANNAPO', 'Annapolis', 'USA', 'Maryland', 33200, 39, -76),
('ANTWER', 'Antwerpen', 'B', 'Antwerpen', 465000, 51, 4),
('AOSTA', 'Aosta', 'I', 'Aostatal', 35800, 45, 7),
('APIA', 'Apia', 'WS', 'Upolu', 34100, -14, -172),
('ARACAJ', 'Aracaju', 'BR', 'Sergipe', 401000, -11, -37),
('ARCHAN', 'Archangelsk', 'RUS', NULL, 414000, 64, 40),
('ARENDA', 'Arendal', 'N', 'Aust-Agder', 38500, 58, 8),
('ARLON', 'Arlon', 'B', 'Wallonien', 26, 49, 5),
('ASCHAF', 'Aschaffenburg', 'D', 'Bayern', 66152, 50, 9),
('ASCHCH', 'Aschchabad', 'RUS', NULL, 517000, 38, 58),
('ASTRAC', 'Astrachan', 'RUS', NULL, 512000, 46, 48),
('ASUNCI', 'Asuncion', 'PY', NULL, 638000, -26, -57),
('ATHEN', 'Athen', 'GR', NULL, 784000, 38, 24),
('ATLANT', 'Atlanta', 'USA', 'Georgia', 394000, 33, -84),
('AUGSBU', 'Augsburg', 'D', 'Bayern', 258457, 48, 11),
('AUGUST', 'Augusta', 'USA', 'Maine', 21819, 44, -70),
('AUSTIN', 'Austin', 'USA', 'Texas', 502000, 30, -97),
('BAD_HE', 'Bad Hersfeld', 'D', 'Hessen', 31403, 51, 9),
('BAD_TO', 'Bad Tölz', 'D', 'Bayern', 16551, 47, 11),
('BAGDAD', 'Bagdad', 'IRQ', NULL, 4040000, 33, 44),
('BAIRIK', 'Bairiki', 'KIR', NULL, 2100, 1, 173),
('BAKHTA', 'Bakhtaran', 'IR', 'Boyer Ahmad Kohkiluyeh', 290600, 34, 47),
('BAKU', 'Baku', 'AZ', NULL, 1100000, 40, 49),
('BALTIM', 'Baltimore', 'USA', 'Maryland', 726000, 39, -76),
('BAMAKO', 'Bamako', 'RMM', NULL, 746000, 12, -8),
('BANDAR', 'Bandar Seri Begawan', 'BRU', NULL, 137000, 4, 115),
('BANDUN', 'Bandung', 'RI', 'Java Barat', 2100000, -7, 107),
('BANGAL', 'Bangalore', 'IND', 'Karnataka', 2480000, 13, 77),
('BANGKO', 'Bangkok', 'THA', NULL, 5600000, 13, 100),
('BANGUI', 'Bangui', 'RCA', '', 597000, 4, 18),
('BANJUL', 'Banjul', 'WAG', NULL, 42300, 13, -16),
('BARI', 'Bari', 'I', 'Apulien', 339000, 42, 16),
('BASSET', 'Basseterre', 'SCN', 'Saint Kitts/Nevis', 12600, 17, -62),
('BATON_', 'Baton Rouge', 'USA', 'Louisiana', 220000, 30, -91),
('BAUTZE', 'Bautzen', 'D', 'Sachsen', 46658, 51, 14),
('BEIRUT', 'Beirut', 'RL', NULL, 1500000, 34, 35),
('BELEM', 'Belem', 'BR', 'Para', 1200000, -1, -48),
('BELFAS', 'Belfast', 'GB', 'Nordirland', 281000, 54, -6),
('BELGRA', 'Belgrad', 'YU', 'Beograd', 1200000, 44, 20),
('BELMOP', 'Belmopan', 'BH', NULL, 3900, 17, -89),
('BELO_H', 'Belo Horizonte', 'BR', 'Minas Gerais', 2050000, -20, -44),
('BENGAS', 'Bengasi', 'LAR', NULL, 650629, 32, 20),
('BERGEN', 'Bergen', 'N', 'Hordaland', 218000, 60, 5),
('BERLIN', 'Berlin', 'D', 'Berlin', 3458763, 52, 13),
('BERN', 'Bern', 'CH', 'Bern', 317000, 47, 7),
('BERNBU', 'Bernburg', 'D', 'Sachsen-Anhalt', 71690, 52, 12),
('BESANC', 'Besancon', 'F', 'Franche-Conte', 119000, 47, 6),
('BHOPAL', 'Bhopal', 'IND', 'Madhya Pradesh', 1060000, 23, 77),
('BHUBAN', 'Bhubaneswar', 'IND', 'Orissa', 770209, 20, 85),
('BISMAR', 'Bismarck', 'USA', 'North Dakota', 49300, 46, -101),
('BISSAU', 'Bissau', 'GUB', NULL, 198000, 11, -16),
('BOA_VI', 'Boa Vista', 'BR', 'Roraima', 143000, 2, -60),
('BOCHUM', 'Bochum', 'D', 'Nordrhein-Westfalen', 398467, 51, 7),
('BODOE', 'Bodoe', 'N', 'Nordland', 39700, 67, 14),
('BOGOTA', 'Bogota', 'CO', 'Cundinamarca', 3960000, 4, -74),
('BOISE', 'Boise', 'USA', 'Idaho', 126000, 43, -116),
('BOLOGN', 'Bologna', 'I', 'Emilia-Romagna', 395000, 44, 11),
('BOMBAY', 'Bombay', 'IND', 'Maharashtra', 9990000, 19, 72),
('BONN', 'Bonn', 'D', 'Nordrhein-Westfalen', 302873, 50, 7),
('BORDEA', 'Bordeaux', 'F', 'Aquitaine', 685000, 45, 0),
('BOSTON', 'Boston', 'USA', 'Massachusetts', 574000, 42, -71),
('BRANDE', 'Brandenburg', 'D', 'Brandenburg', 84493, 52, 12),
('BRASIL', 'Brasilia', 'BR', 'Distrito Federal', 1800000, -15, -48),
('BRATIS', 'Bratislava', 'SK', 'Bratislava', 452000, 48, 17),
('BRAZZA', 'Brazzaville', 'RCB', NULL, 938000, -5, 15),
('BREGEN', 'Bregenz', 'A', 'Voralberg', 27923, 47, 9),
('BREMEN', 'Bremen', 'D', 'Hansestadt Bremen', 548826, 54, 8),
('BREMER', 'Bremerhafen', 'D', 'Hansestadt Bremen', 128944, 54, 8),
('BRIDGE', 'Bridgetown', 'BB', NULL, 87000, 13, -60),
('BRISBA', 'Brisbane', 'AUS', 'Queensland', 1450000, -27, 153),
('BRUEGG', 'Bruegge', 'B', 'Westflandern', 116000, 51, 2),
('BRUESS', 'Bruessel', 'B', 'Brabant', 952000, 50, 4),
('BUDAPE', 'Budapest', 'H', 'Közep-Magyarorszag', 1900000, 47, 19),
('BUENOS', 'Buenos Aires', 'RA', 'Bundesdistrikt', 3000000, -34, -58),
('BUJUMB', 'Bujumbura', 'BU', 'Bujumbura Mairie', 300000, -3, 29),
('BUKARE', 'Bukarest', 'RO', 'Bucure?ti', 2040000, 26, 44),
('CADIZ', 'Cadiz', 'E', 'Cadiz', 154000, 36, -6),
('CAEN', 'Caen', 'F', 'Basse-Normandie', 116000, 49, 0),
('CAGLIA', 'Cagliari', 'I', 'Sardinien', 174000, 39, 9),
('CALCUT', 'Calcutta', 'IND', 'West Bengal', 4400000, 22, 88),
('CALGAR', 'Calgary', 'CDN', 'Alberta', 829000, 51, -114),
('CAMPEC', 'Campeche', 'MEX', 'Campeche', 669000, 19, -90),
('CAMPOZ', 'Campozona', 'I', 'Molise', NULL, NULL, NULL),
('CANBER', 'Canberra', 'AUS', 'Austr.Cap.Terr.', 313000, -35, 149),
('CARACA', 'Caracas', 'YV', NULL, 1820000, 10, -67),
('CARDIF', 'Cardiff', 'GB', 'Wales', 279000, 51, 3),
('CARSON', 'Carson City', 'USA', 'Nevada', 40400, 39, -120),
('CASABL', 'Casablanca', 'MA', NULL, 2940000, 36, -7),
('CASTRI', 'Castries', 'WL', 'Saint Lucia', 53900, 14, -61),
('CATANZ', 'Catanzaro', 'I', 'Kalabrien', 96900, 39, 16),
('CAYENN', 'Cayenne', 'F', 'Franz.-Guayana', 41600, 5, -52),
('CELLE', 'Celle', 'D', 'Niedersachsen', 73559, 53, 10),
('CEUTA', 'Ceuta', 'E', 'Cadiz', 70700, 36, -5),
('CHANDI', 'Chandigargh', 'IND', 'Punjab', NULL, 30, 76),
('CHANGC', 'Changchun', 'VRC', 'Jilin', 2400000, 43, 125),
('CHANGS', 'Changsha', 'VRC', 'Hunan', 1480000, 28, 113),
('CHARLE', 'Charleston', 'USA', 'West Virginia', 57300, 38, -81),
('CHARLO', 'Charlottetown', 'CDN', 'Prince Edward Island', 15400, 46, -63),
('CHEMNI', 'Chemnitz', 'D', 'Sachsen', 281659, 51, 13),
('CHENGD', 'Chengdu', 'VRC', 'Sichuan', 2670000, 33, 107),
('CHEYEN', 'Cheyenne', 'USA', 'Wyoming', 51000, 41, -105),
('CHICAG', 'Chicago', 'USA', 'Illinois', 2770000, 41, -88),
('CHIHUA', 'Chihuahua', 'MEX', 'Chihuahua', 612000, 28, -106),
('CHILPA', 'Chilpancingo d.l.Bravos', 'MEX', 'Guerrero', 74000, 17, -99),
('CHISIN', 'Chisinau', 'MD', NULL, 647513, 47, 29),
('CIUCHE', 'Ciudad Chetumal', 'MEX', 'Quintana Roo', 23685, 18, -88),
('CIUDAD', 'Ciudad de Guatemala', 'GCA', NULL, 1300000, 14, -90),
('CIUPAN', 'Ciudad de Panama', 'PA', 'Panama', 550000, 9, -79),
('CIUVIC', 'Ciudad Victoria', 'MEX', 'Tamaulipas', 208000, 23, -99),
('CLERMF', 'Clerm.-Ferrand', 'F', 'Auvergne', 140000, 45, 3),
('COCHAB', 'Cochabamba', 'BOL', NULL, 404000, -17, -66),
('COLIMA', 'Colima', 'MEX', 'Colima', 107000, 19, -103),
('COLOMB', 'Colombo', 'CL', 'Western Province', 615000, 7, 80),
('COLUM1', 'Columbia', 'USA', 'South Carolina', 125000, 34, -81),
('COLUMS', 'Columbus', 'USA', 'Ohio', 643000, 39, -83),
('CONAKR', 'Conakry', 'GUI', '', 1300000, 9, -14),
('CONCOR', 'Concord', 'USA', 'New Hampshire', 114000, 43, -71),
('CORDOB', 'Cordoba', 'RA', 'Cordoba', 1200000, -31, -64),
('CORRIE', 'Corrientes', 'RA', 'Corrientes', 268000, -27, -58),
('COTTBU', 'Cottbus', 'D', 'Brandenburg', 120812, 52, 14),
('CUERNA', 'Cuernavaca', 'MEX', 'Morelos', 282000, 19, -99),
('CUIABA', 'Cuiaba', 'BR', 'Mato Grosso', 401000, -15, -56),
('CULIAC', 'Culiacan', 'MEX', 'Sinaloa', 602000, 24, -107),
('CURITI', 'Curitiba', 'BR', 'Parana', 1300000, -25, -49),
('CUZCO', 'Cuzco', 'PE', 'Cuzco', 258000, -13, -72),
('DAKAR', 'Dakar', 'SN', NULL, 1700000, 14, 17),
('DALLAS', 'Dallas', 'USA', 'Texas', 1020000, 32, -97),
('DAMASK', 'Damaskus', 'SYR', NULL, 1440000, 33, 36),
('DARESS', 'Daressalam', 'EAT', NULL, NULL, -6, 39),
('DARWIN', 'Darwin', 'AUS', 'Nordterritorium', 77900, -13, 131),
('DEGGEN', 'Deggendorf', 'D', 'Bayern', 31294, 49, 13),
('DELHI', 'Delhi', 'IND', 'Delhi', 10900000, 28, 77),
('DENVER', 'Denver', 'USA', 'Colorado', 468000, 39, -105),
('DES_MO', 'Des Moines', 'USA', 'Iowa', 195000, 41, -93),
('DESSAU', 'Dessau', 'D', 'Sachsen-Anhalt', 90131, 52, 12),
('DETROI', 'Detroit', 'USA', 'Michigan', 1010000, 42, -83),
('DIJON', 'Dijon', 'F', 'Bourgogne', 152000, 47, 5),
('DILLIN', 'Dillingen', 'D', 'Saarland', 21924, 49, 7),
('DISPUR', 'Dispur', 'IND', 'Assam', 20000, 26, 91),
('JAKART', 'Jakarta', 'RI', 'Jakarta', 9000000, -6, 106),
('DJIBUT', 'Djibuti', 'RD', NULL, NULL, 11, 43),
('DOHA', 'Doha', 'Q', NULL, 217000, 25, 52),
('DONAUW', 'Donauwörth', 'D', 'Bayern', 17999, 49, 11),
('DORTMU', 'Dortmund', 'D', 'Nordrhein-Westfalen', 597024, 52, 8),
('DOUGLA', 'Douglas', 'GB', 'Isle of Man', 25422, 54, -4),
('DOVER', 'Dover', 'USA', 'Delaware', 32800, 39, -75),
('DRAMME', 'Drammen', 'N', 'Buskerud', 50855, 59, 10),
('DRESDE', 'Dresden', 'D', 'Sachsen', 506384, 51, 14),
('DSCHAM', 'Dschambul', 'RUS', NULL, 312000, 42, 71),
('DUALA', 'Duala', 'CAM', 'Littoral', 1338144, 4, 10),
('DUBAI', 'Dubai', 'UAE', NULL, 674000, 25, 55),
('DUBLIN', 'Dublin', 'IRL', 'Dublin', 478000, 53, -6),
('DUESSE', 'Düsseldorf', 'D', 'Nordrhein-Westfalen', 571475, 51, 6),
('DUISBU', 'Duisburg', 'D', 'Nordrhein-Westfalen', 532701, 51, 6),
('DURANG', 'Durango', 'MEX', 'Durango', 414000, 24, -104),
('DURRES', 'Durres', 'AL', 'Durres', 86900, 41, 19),
('DUSHAN', 'Dushanbe', 'TAD', NULL, 582000, 38, 68),
('EDINBU', 'Edinburgh', 'GB', 'Schottland', 421000, 56, -3),
('EDMONT', 'Edmonton', 'CDN', 'Alberta', 617000, 53, -113),
('EILENB', 'Eilenburg', 'D', 'Sachsen', 19939, 51, 13),
('EISENS', 'Eisenstadt', 'A', 'Burgenland', 13250, 48, 17),
('EL_ALA', 'El Alaiun', 'DARS', NULL, 200000, 27, -13),
('ELBASA', 'Elbasan', 'AL', 'Elbasan', 83200, 41, 20),
('EMDEN', 'Emden', 'D', 'Niedersachsen', 51470, 53, 7),
('EMSDET', 'Emsdetten', 'D', 'Nordrhein-Westfalen', 33880, 52, 8),
('ER_RIA', 'Riad', 'KSA', NULL, 4, 25, 47),
('ERFURT', 'Erfurt', 'D', 'Thüringen', 208179, 51, 11),
('ESBJER', 'Esbjerg', 'DK', NULL, 82600, 55, 8),
('ESPOO', 'Espoo', 'SF', 'Uusimaa', 160480, 60, 24),
('ESSEN', 'Essen', 'D', 'Nordrhein-Westfalen', 611827, 52, 7),
('FALUN', 'Falun', 'S', 'Koppabergs laen', 54800, 60, 15),
('FLENSB', 'Flensburg', 'D', 'Schleswig-Holstein', 86630, 55, 9),
('FLOREN', 'Florenz', 'I', 'Toskana', 382000, 43, 11),
('FLORIA', 'Florianopolis', 'BR', 'Santa Catarina', 267000, -27, -58),
('FORMOS', 'Formosa', 'RA', 'Formosa', 36000, -27, -58),
('FORST', 'Forst', 'D', 'Brandenburg', 25543, 52, 15),
('FORT_W', 'Fort Worth', 'USA', 'Texas', 452000, 32, -97),
('FORTAL', 'Fortaleza', 'BR', 'Ceara', 1800000, -3, -38),
('FRANKF', 'Frankfort', 'USA', 'Kentucky', 26000, 38, -85),
('FRANKM', 'Frankfurt/M', 'D', 'Hessen', 647304, 51, 9),
('FRANKO', 'Frankfurt/O', 'D', 'Brandenburg', 79784, 52, 14),
('FREDER', 'Fredericton', 'CDN', 'New Brunswick', 45400, 45, -53),
('FREETO', 'Freetown', 'WAL', 'Sierra Leone', 470000, 8, 13),
('FRIEDR', 'Friedrichshafen', 'D', 'Baden-Wuerttemberg', 56730, 48, 9),
('BISCHK', 'Bischkek', 'KGS', NULL, 597000, 42, 74),
('FUERST', 'Fürstenwalde', 'D', 'Brandenburg', 33823, 52, 14),
('FUESSE', 'Füssen', 'D', 'Bayern', 13582, 48, 11),
('FULDA', 'Fulda', 'D', 'Hessen', 61728, 51, 10),
('FUZHOU', 'Fuzhou', 'VRC', 'Fujian', 1290000, 26, 119),
('GABARO', 'Gabarone', 'RB', NULL, NULL, -25, 26),
('GAEVLE', 'Gaevle', 'S', 'Gaevleborgs laen', 90300, 60, 17),
('GANDHI', 'Gandhinagar', 'IND', 'Gujarat', 122000, 23, 72),
('GANGTO', 'Gangtok', 'IND', 'Sikkim', 25000, 27, 88),
('GENF', 'Genf', 'CH', 'Genf', 391000, 46, 7),
('GENT', 'Gent', 'B', 'Ostflandern', 227000, 51, 3),
('GENUA', 'Genua', 'I', 'Ligurien', 660000, 44, 9),
('GEORGE', 'Georgetown', 'GUY', NULL, 248000, 6, -59),
('GHOM', 'Ghom', 'IR', 'Zentralprovinz', 247219, 34, 50),
('GIBRAL', 'Gibraltar', 'GB', 'Gibraltar', 27300, 37, -5),
('GOERLI', 'Görlitz', 'D', 'Sachsen', 66404, 51, 15),
('GOETEB', 'Goeteborg', 'S', 'Goeteborgs och Bohus laen', 445000, 57, 12),
('GOETTI', 'Göttingen', 'D', 'Niedersachsen', 126451, 52, 10),
('GOIANI', 'Goiania', 'BR', 'Goias', 958000, -16, -49),
('GRAZ', 'Graz', 'A', 'Steiermark', 250000, 47, 15),
('GRIMMA', 'Grimma', 'D', 'Sachsen', 19033, 51, 13),
('GUADAL', 'Guadalajara', 'MEX', 'Jalisco', 3150000, 20, -103),
('GUANAJ', 'Guanajuato', 'MEX', 'Guanajuato', 48000, 21, -101),
('GUAYAQ', 'Guayaquil', 'EC', NULL, 1900000, -2, -80),
('GUIANG', 'Guiang', 'VRC', 'Guizhou', NULL, 26, 106),
('HAEMEE', 'Haemeenlinna', 'SF', 'Haeme', 44200, 61, 24),
('HAERNO', 'Haernoesand', 'S', 'Vaesternorrlands laen', 27600, 62, 18),
('HAFNAR', 'Hafnarfjoerdur', 'IS', NULL, 12000, 64, -22),
('HALIFA', 'Halifax', 'CDN', 'Nova Scotia', 114000, 44, -63),
('HALLE', 'Halle', 'D', 'Sachsen-Anhalt', 276624, 51, 12),
('HALMST', 'Halmstad', 'S', 'Hallands laen', 83100, 56, 13),
('HAMADA', 'Hamadan', 'IR', 'Hamadan', 350000, 34, 48),
('HAMAR', 'Hamar', 'N', 'Hedmark', 26300, 60, 11),
('HAMBUR', 'Hamburg', 'D', 'Hansestadt Hamburg', 1707986, 53, 10),
('HAMELN', 'Hameln', 'D', 'Niedersachsen', 58762, 53, 9),
('HAMMER', 'Hammerfest', 'N', 'Finnmark', 6900, 70, 23),
('HANGZH', 'Hangzhou', 'VRC', 'Zhejiang', 1740000, 30, 125),
('HANNOV', 'Hannover', 'D', 'Niedersachsen', 522574, 52, 9),
('HANOI', 'Hanoi', 'VN', NULL, 2200000, 21, 105),
('HARBIN', 'Harbin', 'VRC', 'Heilongjiang', 3100000, 45, 126),
('HARRIS', 'Harrisburg', 'USA', 'Pennsylvania', 53400, 40, -77),
('HARTFO', 'Hartford', 'USA', 'Connecticut', 133000, 41, -72),
('HASSEL', 'Hasselt', 'B', 'Limburg', 67100, 51, 5),
('HAVANN', 'Havanna', 'C', 'Ciudad de La Habana', 2180000, 23, -82),
('HEFEI', 'Hefei', 'VRC', 'Anhui', 733000, 32, 117),
('HEILBR', 'Heilbronn', 'D', 'Baden-Wuerttemberg', 121556, 49, 9),
('HELENA', 'Helena', 'USA', 'Montana', 24600, 46, -112),
('HELSIN', 'Helsinki', 'SF', 'Uusimaa', 516000, 60, 24),
('HENDER', 'Hendersonville', 'USA', 'North Carolina', 6862, 35, -82),
('HERMAN', 'Hermannsverk', 'N', 'Sogn og Fjordane', 706, 61, 6),
('HERMOS', 'Hermosillo', 'MEX', 'Sonora', 449000, 29, -111),
('HIROSH', 'Hiroshima', 'J', NULL, 1100000, 34, 132),
('HOBART', 'Hobart', 'AUS', 'Tasmania', 193000, -43, 147),
('HO-CHI', 'Ho-Chi-Minh-Stadt', 'VN', NULL, 4300000, 10, 106),
('HOEXTE', 'Höxter', 'D', 'Nordrhein-Westfalen', 33463, 52, 9),
('HOHHOT', 'Hohhot', 'VRC', 'Innere Mongolei', 653000, 41, 113),
('HOMS', 'Homs', 'SYR', 'Homs', 537000, 35, 37),
('HONIAR', 'Honiara', 'SAL', 'Guadalcanal', 36900, -9, 160),
('HONOLU', 'Honolulu', 'USA', 'Hawaii', 365000, 21, -158),
('HYDERA', 'Hyderabad', 'IND', 'Andhra Pradesh', 4300000, 17, 78),
('IMPHAL', 'Imphal', 'IND', 'Manipur', 199000, 24, 94),
('INDIAN', 'Indianapolis', 'USA', 'Indiana', 752000, 39, -86),
('INGOLS', 'Ingolstadt', 'D', 'Bayern', 112929, 48, 11),
('INNSBR', 'Innsbruck', 'A', 'Tirol', 128000, 47, 11),
('IQUITO', 'Iquitos', 'PE', 'Loreto', 266000, -3, -73),
('IRKUTS', 'Irkutsk', 'RUS', 'Sibirien', 585000, 52, 104),
('ISFAHA', 'Isfahan', 'IR', 'Isfahan', 1300000, 32, 51),
('ISLAMA', 'Islamabad', 'PAK', 'Punjab', 900000, 34, 73),
('ITANAG', 'Itanagar', 'IND', 'Arunachal Pradesh', NULL, 27, 93),
('JACKSO', 'Jackson', 'USA', 'Mississippi', 197000, 32, -90),
('JAIPUR', 'Jaipur', 'IND', 'Rajasthan', 1460000, 27, 75),
('JAKUTS', 'Jakutsk', 'RUS', 'Fernost', 236000, 62, 129),
('JALAPA', 'Jalapa Enriquez', 'MEX', 'Veracruz', 288000, 19, -97),
('JAMMU', 'Jammu', 'IND', 'Jammu und Kashmir', 206000, 32, 74),
('JAUNDE', 'Jaunde', 'CAM', 'Centre', 1299446, 4, 12),
('JEFFER', 'Jefferson City', 'USA', 'Missouri', 35500, 38, -92),
('JENA', 'Jena', 'D', 'Thüringen', 100278, 51, 12),
('ERIWAN', 'Eriwan', 'AM', NULL, 1200000, 40, 44),
('JERUSA', 'Jerusalem', 'IL', NULL, 557000, 31, 35),
('JINAN', 'Jinan', 'VRC', 'Shandong', 2050000, 36, 117),
('JOAO_P', 'Joao Pessoa', 'BR', 'Paraiba', 497000, -7, -35),
('JOENKO', 'Joenkoeping', 'S', 'Joenkoepings laen', 114000, 57, 14),
('JOENSU', 'Joensuu', 'SF', 'Nordkarelien', 49200, 62, 29),
('JOHANN', 'Johannesburg', 'RSA', 'Gauteng', 1900000, -26, 28),
('JOKKMO', 'Jokkmokk', 'S', 'Norrbottens laen', 6822, 66, 19),
('YOKOHA', 'Yokohama', 'J', NULL, 3300000, 35, 139),
('JUNEAU', 'Juneau', 'USA', 'Alaska', 26800, 58, 136),
('JYVAES', 'Jyvaeskylae', 'SF', 'Mittelfinnland', 71800, 62, 25),
('KABUL', 'Kabul', 'AF', NULL, 1400000, 34, 69),
('KAIRO', 'Kairo', 'ET', NULL, 7000000, 30, 31),
('KALMAR', 'Kalmar', 'S', 'Kalmar laen', 58100, 56, 16),
('KAMPAL', 'Kampala', 'EAU', NULL, 773000, 0, 32),
('KANSAS', 'Kansas City', 'USA', 'Missouri', 150000, 39, -95),
('KANTON', 'Kanton', 'VRC', 'Gwangdong', 3560000, 23, 114),
('KAPSTA', 'Kapstadt', 'RSA', 'Westkap', 2350000, -34, 18),
('KARLSK', 'Karlskrona', 'S', 'Blekinge laen', 60600, 56, 15),
('KARLSR', 'Karlsruhe', 'D', 'Baden-Wuerttemberg', 277191, 49, 8),
('KARLST', 'Karlstad', 'S', 'Vaermlands laen', 78900, 59, 13),
('KASAN', 'Kasan', 'RUS', 'Wolga', 1100000, 55, 49),
('KASSEL', 'Kassel', 'D', 'Hessen', 200927, 51, 9),
('KATMAN', 'Katmandu', 'NEP', NULL, 393494, 27, 85),
('KAVARA', 'Kavaratti', 'IND', 'Lakshadweep', NULL, 10, 72),
('KEFLAV', 'Keflavik', 'IS', NULL, 7600, 64, -23),
('KEMPTE', 'Kempten', 'D', 'Bayern', 61606, 48, 10),
('KHARTU', 'Khartum', 'EAS', NULL, 925000, 15, 32),
('KIEL', 'Kiel', 'D', 'Schleswig-Holstein', 243728, 54, 11),
('KIEW', 'Kiew', 'UA', NULL, 2600000, 50, 30),
('KIGALI', 'Kigali', 'RWA', NULL, 235000, -2, 30),
('KINGSJ', 'Kingston', 'JA', NULL, 101000, 18, -77),
('KINGST', 'Kingstown', 'WV', 'Saint Vincent', 26500, 13, -61),
('KINSHA', 'Kinshasa', 'ZRE', NULL, 4700000, -4, 15),
('KLAGEN', 'Klagenfurt', 'A', 'Kaernten', 90000, 46, 14),
('KOBLEN', 'Koblenz', 'D', 'Rheinland-Pfalz', 109332, 50, 7),
('KOELN', 'Köln', 'D', 'Nordrhein-Westfalen', 964346, 51, 7),
('KOHIMA', 'Kohima', 'IND', 'Nagaland', NULL, 25, 94),
('KOLONI', 'Kolonia', 'FSM', NULL, 6300, 7, 158),
('KONSTA', 'Konstanz', 'D', 'Baden-Wuerttemberg', 76960, 48, 9),
('KONZ', 'Konz', 'D', 'Rheinland-Pfalz', 17009, 49, 6),
('KOPENH', 'Kopenhagen', 'DK', NULL, 1360000, 55, 12),
('KORCE', 'Korce', 'AL', 'Korce', 67100, 40, 20),
('KOROR', 'Koror', 'PAL', NULL, 10500, 7, 134),
('KOTKA', 'Kotka', 'SF', 'Kymi', 56300, 60, 26),
('KRASNO', 'Krasnojarsk', 'RUS', 'Sibirien', 869000, 56, 93),
('KRISTS', 'Kristiansand', 'N', 'Vest-Agder', 62640, 58, 8),
('KRISTI', 'Kristianstad', 'S', 'Kristianstads laen', 73800, 56, 14),
('KUALAL', 'Kuala Lumpur', 'MY', NULL, 1100000, 3, 101),
('KUIBYS', 'Kuibyschew', 'RUS', 'Kuibyschew', 1200000, 52, 50),
('KUNMIN', 'Kunming', 'VRC', 'Yunnan', 1450000, 25, 102),
('KUOPIO', 'Kuopio', 'SF', 'Kuopio', 83100, 62, 27),
('KUWAIT', 'Kuwait City', 'KT', 'Kuwait', 31200, 29, 47),
('KYOTO', 'Kyoto', 'J', NULL, 1450000, 35, 135),
('LA_PAZ', 'La Paz', 'BOL', NULL, 713000, -16, -68),
('LA_PLA', 'La Plata', 'RA', 'Buenos Aires', 543000, -35, -58),
('LA_RIO', 'La Rioja', 'RA', 'La Rioja', 106000, -29, -67),
('LAGOS', 'Lagos', 'WAN', NULL, 1500000, 6, 3),
('LAHTI', 'Lahti', 'SF', 'Haeme', 94700, 60, 25),
('LANDSB', 'Landsberg', 'D', 'Bayern', 24883, 48, 11),
('LANDSH', 'Landshut', 'D', 'Bayern', 59100, 49, 12),
('LANSIN', 'Lansing', 'USA', 'Michigan', 120000, 42, -84),
('LANZHO', 'Lanzhou', 'VRC', 'Gansu', 1320000, 36, 104),
('LAPPEE', 'Lappeenrenta', 'SF', 'Kymi', 53922, 60, 26),
('LAQUIL', 'L''Aquila', 'I', 'Abbruzzen', NULL, 42, 13),
('LAS_VE', 'Las Vegas', 'USA', 'Nevada', 368000, 36, -115),
('NICOSI', 'Nicosia', 'CY', NULL, 228000, 35, 33),
('LEIPZI', 'Leipzig', 'D', 'Sachsen', 457173, 51, 12),
('LENING', 'Leningrad', 'RUS', 'Nordwestrussland', 4680000, 60, 30),
('LEVERK', 'Leverkusen', 'D', 'Nordrhein-Westfalen', 162977, 51, 7),
('LHASA', 'Lhasa', 'VRC', 'Tibet', 107000, 29, 91),
('LIBREV', 'Libreville', 'GAB', NULL, 420000, 0, 9),
('LIECHT', 'Liechtenstein', 'FL', '', 27714, 47, 9),
('LILLE', 'Lille', 'F', 'Nord-Pas-de-Ca.', 178000, 50, 3),
('LILLEH', 'Lillehammer', 'N', 'Oppland', 24400, 61, 10),
('LILONG', 'Lilongwe', 'MW', NULL, 676750, -14, 34),
('LIMA', 'Lima', 'PE', 'Lima Metropolitana', 6400000, -12, -77),
('LIMOGE', 'Limoges', 'F', 'Limousin', 136000, 45, 1),
('LINCOL', 'Lincoln', 'USA', 'Nebraska', 203000, 40, -96),
('LINDAU', 'Lindau', 'D', 'Baden-Wuerttemberg', 23951, 48, 10),
('LINGEN', 'Lingen', 'D', 'Niedersachsen', 52289, 53, 7),
('LINKOE', 'Linkoeping', 'S', 'Oestergoetlands laen', 130000, 58, 15),
('LINZ', 'Linz', 'A', 'Oberösterreich', 211021, 48, 14),
('LISSAB', 'Lissabon', 'P', '', 678000, 28, -9),
('LITTLE', 'Little Rock', 'USA', 'Arkansas', 178000, 34, -92),
('LJUBLJ', 'Ljubljana', 'SLO', NULL, 270000, 46, 15),
('LOBITO', 'Lobito', 'AN', 'Benguela', 150000, -12, 13),
('LOME', 'Lome', 'TG', 'Thurgau', 450000, 6, 1),
('LONDON', 'London', 'GB', 'England', 7100000, 51, -1),
('LOS_AN', 'Los Angeles', 'USA', 'California', 3550000, 34, -118),
('LUANDA', 'Luanda', 'AN', 'Luanda', 2700000, -9, 13),
('LUCKNO', 'Lucknow', 'IND', 'Uttar Pradesh', 1600000, 27, 81),
('LUDWIG', 'Ludwigshafen', 'D', 'Rheinland-Pfalz', 167098, 49, 8),
('LUETTI', 'Luettich', 'B', 'Luettich', 192000, 50, 5),
('LULEO', 'Luleo', 'S', 'Norrbottens laen', 66526, 65, 22),
('LUSAKA', 'Lusaka', 'Z', NULL, 1267458, -15, 28),
('LUTHER', 'Lutherstadt Wittenberg', 'D', 'Sachsen-Anhalt', 51658, 52, 13),
('LUXEMB', 'Luxemburg', 'L', '', 76400, 49, 6),
('LYON', 'Lyon', 'F', 'Rhone-Alpes', 422000, 45, 4),
('MACAO', 'Macao', 'VRC', 'Macao', 406000, 22, 113),
('MACAPA', 'Macapa', 'BR', 'Amapa', 179000, 0, -52),
('MACEIO', 'Maceio', 'BR', 'Alagoas', 688000, -9, -36),
('MADISO', 'Madison', 'USA', 'Wisconsin', 195000, 43, -89),
('MADRAS', 'Madras', 'IND', 'Tamil Nadu', 3800000, 13, 80),
('MADRID', 'Madrid', 'E', '', 3030000, 40, 3),
('MAGDEB', 'Magdeburg', 'D', 'Sachsen-Anhalt', 235073, 52, 12),
('MAILAN', 'Mailand', 'I', 'Lombardei', 1300000, 45, 9),
('MAINZ', 'Mainz', 'D', 'Rheinland-Pfalz', 184752, 50, 8),
('MALABO', 'Malabo', 'RGE', 'Bioko Norte', 50000, 4, 9),
('MALE', 'Male', 'RMAL', NULL, 104403, 4, 74),
('MALMOE', 'Malmoe', 'S', 'Malmoehus laen', 243000, 55, 13),
('MANAGU', 'Managua', 'NIC', NULL, 820000, 12, -86),
('MANAMA', 'Manama', 'BA', NULL, 137000, 26, 51),
('MANAUS', 'Manaus', 'BR', 'Amazonas', 1200000, -3, -60),
('MANILA', 'Manila', 'PI', 'Luzon', 1700000, 14, 121),
('MANNHE', 'Mannheim', 'D', 'Baden-Wuerttemberg', 312216, 49, 8),
('MAPUTO', 'Maputo', 'MOS', NULL, 1100000, -26, 33),
('MARACA', 'Maracaibo', 'YV', NULL, 1200000, 10, -71),
('MARIEH', 'Mariehamn', 'SF', 'Aland', 10300, 60, 19),
('MARIES', 'Mariestad', 'S', 'Skaraborgs laen', 24700, 58, 13),
('MARSEI', 'Marseille', 'F', 'Cote Azur', 808000, 43, 5),
('MASERU', 'Maseru', 'LS', NULL, 367000, -29, 27),
('MASHHA', 'Mashhad', 'IR', 'Khorazan', 1470000, 36, 59),
('MASKAT', 'Maskat', 'OMA', NULL, 40900, 34, 59),
('MBABAN', 'Mbabane', 'SD', NULL, 52000, -25, 31),
('MEDELL', 'Medellin', 'CO', 'Antioquia', 1970000, 6, -75),
('MEININ', 'Meiningen', 'D', 'Thüringen', 22777, 51, 10),
('MEISSE', 'Meissen', 'D', 'Sachsen', 31233, 51, 13),
('MELBOU', 'Melbourne', 'AUS', 'Victoria', 3300000, -37, 145),
('MELILL', 'Melilla', 'E', 'Cadiz', 58100, 35, -3),
('MENDOZ', 'Mendoza', 'RA', 'Mendoza', 122000, -33, -69),
('MEPPEN', 'Meppen', 'D', 'Niedersachsen', 32356, 53, 7),
('MERIDA', 'Merida', 'MEX', 'Yucatan', 557000, 21, -89),
('MERSEB', 'Merseburg', 'D', 'Sachsen-Anhalt', 40650, 51, 12),
('MEXICA', 'Mexicali', 'MEX', 'Baja California Norte', 695000, 32, -115),
('MEXICO', 'Mexico City', 'MEX', 'Distrito Federal', 16700000, 19, -99),
('MIAMI', 'Miami', 'USA', 'Florida', 373000, 25, -80),
('MIKKEL', 'Mikkeli', 'SF', 'Mikkeli', 32400, 61, 27),
('MINDEN', 'Minden', 'D', 'Nordrhein-Westfalen', 83307, 52, 9),
('MINSK', 'Minsk', 'BY', NULL, 1700000, 53, 27),
('MMABAT', 'Mmabatho', 'JB', NULL, 9000, -26, 26),
('MOGADI', 'Mogadischu', 'SP', NULL, 900000, 2, 45),
('MOLDE', 'Molde', 'N', 'Moere og Romsdal', 21448, 62, 7),
('MOMBAS', 'Mombasa', 'EAK', NULL, 799900, -4, 39),
('MONACO', 'Monaco-Ville', 'MC', NULL, 1234, 44, 7),
('MONROV', 'Monrovia', 'LB', NULL, 465000, 6, -11),
('MONS', 'Mons', 'B', 'Hennegau', 92700, 50, 4),
('MONTER', 'Monterrey', 'MEX', 'Nuevo Leon', 1900000, 25, -100),
('MONTEV', 'Montevideo', 'U', 'Montevideo', 1380000, -35, -57),
('MONTGO', 'Montgomery', 'USA', 'Alabama', 195000, 32, -86),
('MONTPR', 'Montpelier', 'USA', 'Vermont', 8200, 44, -72),
('MONTPE', 'Montpellier', 'F', 'Lang.-Rousilli.', 211000, 43, 3),
('MONTRE', 'Montreal', 'CDN', 'Quebec', 3300000, 45, -74),
('MORELI', 'Morelia', 'MEX', 'Michoacan', 490000, 19, -101),
('MORONI', 'Moroni', 'KOM', NULL, 30000, -12, 43),
('MOSKAU', 'Moskau', 'RUS', 'Zentralrussland', 8600000, 55, 37),
('MOSS', 'Moss', 'N', 'Oestfold', 24517, 59, 10),
('MUEHLD', 'Mühldorf', 'D', 'Bayern', 17800, 48, 13),
('MUENCH', 'München', 'D', 'Bayern', 1225809, 48, 11),
('MUENST', 'Münster', 'D', 'Nordrhein-Westfalen', 265748, 52, 8),
('MURMAN', 'Murmansk', 'RUS', 'Nordwestrussland', 407000, 69, 33),
('NAIROB', 'Nairobi', 'EAK', NULL, 1500000, -1, 36),
('NAMUR', 'Namur', 'B', 'Namur', 439000, 50, 4),
('NANCHA', 'Nanchang', 'VRC', 'Jiangxi', 1420000, 28, 115),
('NANCY', 'Nancy', 'F', 'Lorrain', 102300, 48, 6),
('NANJIN', 'Nanjing', 'VRC', 'Jiangsu', 2430000, 32, 119),
('NANNIN', 'Nanning', 'VRC', 'Guangxi', 1070000, 22, 108),
('NANTES', 'Nantes', 'F', 'Loire-Atlantique', 251000, 47, 1),
('NARVIK', 'Narvik', 'N', 'Nordland', 18754, 68, 17),
('NASHVI', 'Nashville', 'USA', 'Tennessee', 505000, 36, -86),
('NASSAU', 'Nassau', 'BF', 'New Providence', 210000, 25, -77),
('NATAL', 'Natal', 'BR', 'Rio Grande do Norte', 639000, -6, -35),
('NDJAM', 'N''Djamena', 'TCH', NULL, 760000, 12, 15),
('NEAPEL', 'Neapel', 'I', 'Kampanien', 1050000, 40, 14),
('NEUBRA', 'Neubrandenburg', 'D', 'Mecklenburg-Vorpommern', 79041, 54, 13),
('NEUBUR', 'Neuburg', 'D', 'Bayern', 27000, 49, 11),
('NEUQUE', 'Neuquen', 'RA', 'Neuquen', 265000, -39, -68),
('NEW_YO', 'New York', 'USA', 'New York', 18200000, 40, -74),
('NIAMEY', 'Niamey', 'RN', NULL, 746000, 13, 2),
('NIENBU', 'Nienburg', 'D', 'Niedersachsen', 32942, 53, 9),
('NUAKSC', 'Nouakchott', 'RIM', NULL, 760500, 18, -16),
('NUERNB', 'Nürnberg', 'D', 'Bayern', 492864, 49, 11),
('NUKUAL', 'Nukualofa', 'TON', NULL, 28899, 20, 175),
('NUUK', 'Nuuk', 'DK', 'Groenland', 8300, 64, -52),
('NYKOEP', 'Nykoeping', 'S', 'Soedermanslands laen', 48300, 58, 17),
('OAXACA', 'Oaxaca de Juarez', 'MEX', 'Oaxaca', 114900, 17, -96),
('ODENSE', 'Odense', 'DK', NULL, 184000, 55, 10),
('OEREBR', 'Oerebro', 'S', 'Oerebro laen', 119000, 59, 15),
('OESTER', 'Oestersund', 'S', 'Jaemtlands laen', 59700, 63, 14),
('OKLAHO', 'Oklahoma City', 'USA', 'Oklahoma', 445000, 35, -97),
('OLYMPI', 'Olympia', 'USA', 'Washington', 33800, 47, -123),
('ORAN', 'Oran', 'AG', 'Oran', 640000, 35, 0),
('ORLEAN', 'Orleans', 'F', 'Centre', 484000, 47, 1),
('OSLO', 'Oslo', 'N', 'Oslo', 489000, 59, 11),
('OTTAWA', 'Ottawa', 'CDN', 'Ontario', 1000000, 45, -76),
('OUAGAD', 'Ouagadougou', 'BF', 'Burkina Faso', 934000, 12, -2),
('OULU', 'Oulu', 'SF', 'Oulo', 104000, 65, 25),
('PACHUC', 'Pachuca de Soto', 'MEX', 'Hidalgo', 179000, 20, -98),
('PALEMB', 'Palembang', 'RI', 'Sumatera Selatan', 1400000, -6, 104),
('PANAJI', 'Panaji', 'IND', 'Goa Daman & Diu', NULL, 15, 74),
('PARAMA', 'Paramaribo', 'SME', NULL, 201000, 5, -55),
('PARANA', 'Parana', 'RA', 'Entre Rios', 277000, -32, -60),
('PARIS', 'Paris', 'F', 'Ile de France', 2200000, 48, 2),
('PARLER', 'Parlermo', 'I', 'Sizilien', 686000, 38, 13),
('PASSAU', 'Passau', 'D', 'Bayern', 50798, 49, 13),
('PATNA', 'Patna', 'IND', 'Bihar', 917000, 25, 85),
('PEKING', 'Peking', 'VRC', 'Peking', 11300000, 39, 116),
('PERTH', 'Perth', 'AUS', NULL, 1200000, -32, 115),
('PERUGI', 'Perugia', 'I', 'Umbrien', 152000, 43, 12),
('PHNOMP', 'Phnom Penh', 'VRK', NULL, 920000, 11, 105),
('PHOENI', 'Phoenix', 'USA', 'Arizona', 1050000, 33, 112),
('PIERRE', 'Pierre', 'USA', 'South Dakota', 12900, 44, -100),
('POITIE', 'Poitiers', 'F', 'Poitou-Charent.', 82500, 46, 0),
('PONDIC', 'Pondicherry', 'IND', 'Pondicherry', 894000, 12, 79),
('PORI', 'Pori', 'SF', 'Turku-Pori', 76400, 61, 21),
('PORT_A', 'Port au Prince', 'RH', NULL, 846000, 18, -72),
('PORT_B', 'Port Blair', 'IND', 'Andaman & Nicobar Isl.', 748000, 11, 92),
('PORT_L', 'Port Louis', 'MS', NULL, 170000, -20, 57),
('PORT_M', 'Port Moresby', 'PNG', NULL, 174000, -9, 147),
('PORT_O', 'Port of Spain', 'TT', 'Trinidad und Tobago', 150000, 10, -61),
('PORT_V', 'Port Vila', 'VAN', NULL, 15759, NULL, NULL),
('PORTOA', 'Porto Alegre', 'BR', 'Rio Grande do Sul', 1300000, -30, -52),
('PORTON', 'Porto Novo', 'RPB', NULL, NULL, 6, 2),
('PORTOV', 'Porto Velho', 'BR', 'Rondonia', 297000, -9, -64),
('POSADA', 'Posadas', 'RA', 'Misiones', 220000, -27, -56),
('POTENZ', 'Potenza', 'I', 'Basilicata', 66000, 40, 15),
('POTSDA', 'Potsdam', 'D', 'Brandenburg', 134773, 52, 13),
('PRAG', 'Prag', 'CZ', 'Tschechoslowakei', 1197000, 50, 14),
('PRAIA', 'Praia', 'KAP', 'Kap Verde', 61700, 15, -24),
('PRETOR', 'Pretoria', 'RSA', 'Suedafrika', 1080000, -25, 28),
('PROVID', 'Providence', 'USA', 'Rhode Island', 151000, 41, -71),
('PUEBLA', 'Puebla', 'MEX', 'Puebla', 1200000, 19, -98),
('QUEBEC', 'Quebec', 'CDN', 'Quebec', 168000, 46, -71),
('QUERET', 'Queretaro', 'MEX', 'Queretaro', 454000, 20, -100),
('QUITO', 'Quito', 'EC', NULL, 1400000, 0, -78),
('RABAT', 'Rabat', 'MA', 'Mindanao', 13300, 34, -7),
('RALEIG', 'Raleigh', 'USA', 'North Carolina', 237000, 35, -78),
('RANDER', 'Randers', 'DK', NULL, 62000, 56, 10),
('RANGOO', 'Rangoon', 'BUR', '', 2458712, 16, 96),
('RAPID_', 'Rapid City', 'USA', 'South Dakota', 46492, 44, -103),
('RASHT', 'Rasht', 'IR', 'Gilan', 294000, 37, 49),
('RATHEN', 'Rathenow', 'D', 'Brandenburg', 28339, 53, 12),
('RAWSON', 'Rawson', 'RA', 'Chubut', 19200, -43, -65),
('RAYYAN', 'Rayyan', 'Q', 'Katar', 91996, NULL, NULL),
('RECIFE', 'Recife', 'BR', 'Pernambuco', 1300000, -8, -35),
('REGENS', 'Regensburg', 'D', 'Bayern', 146000, 49, 12),
('REGINA', 'Regina', 'CDN', 'Saskatchewan', 179000, 50, -104),
('REIMS', 'Reims', 'F', 'Champ.-Ardenne', 185000, 49, 4),
('RENNES', 'Rennes', 'F', 'Bretagne', 204000, 48, -1),
('RESIST', 'Resistencia', 'RA', 'Chaco', 298000, -27, -59),
('REYKJA', 'Reykjavik', 'IS', NULL, 105000, 64, -22),
('RHEINE', 'Rheine', 'D', 'Nordrhein-Westfalen', 75030, 52, 7),
('RICHMO', 'Richmond', 'USA', 'Virginia', 203000, 37, -77),
('RIEDLI', 'Riedlingen', 'D', 'Baden-Wuerttemberg', 9686, 48, 9),
('RIESA', 'Riesa', 'D', 'Sachsen', 40491, 51, 13),
('RIGA', 'Riga', 'LV', NULL, 827000, 57, 14),
('RIO_BR', 'Rio Branco', 'BR', 'Acre', 197000, -10, -68),
('RIO_DE', 'Rio de Janeiro', 'BR', 'Rio de Janeiro', 5550000, -23, -43),
('RIO_GA', 'Rio Gallegos', 'RA', 'Santa Cruz', 64600, -51, -69),
('ROM', 'Rom', 'I', 'Latium', 2680000, 41, 14),
('ROSARI', 'Rosario', 'RA', 'Santa Fe', 1080000, -33, -61),
('ROSEAU', 'Roseau', 'WD', NULL, 20800, 15, -61),
('ROSENH', 'Rosenheim', 'D', 'Bayern', 58908, 48, 13),
('ROSTOC', 'Rostock', 'D', 'Mecklenburg-Vorpommern', 221029, 54, 12),
('ROUEN', 'Rouen', 'F', 'Haute-Normandie', 105000, 49, 1),
('ROVANM', 'Rovaniemi', 'SF', 'Lappland', 34900, 66, 24),
('ROVANI', 'Rovaniemi', 'SF', 'Lappland', 34900, 66, 24),
('SAARBR', 'Saarbrücken', 'D', 'Saarland', 187599, 49, 7),
('SAARLO', 'Saarlouis', 'D', 'Saarland', 38439, 49, 7),
('SACRAM', 'Sacramento', 'USA', 'California', 393000, 38, -122),
('SAINTG', 'Saint George''s', 'WG', NULL, 30000, 12, -61),
('SAINTJ', 'Saint John''s', 'AC', NULL, 36000, 17, -62),
('SALEM', 'Salem', 'USA', 'Oregon', 116000, 44, -123),
('SALISB', 'Salisbury', 'ZW', NULL, 1200000, -18, 31),
('SALT_L', 'Salt Lake City', 'USA', 'Utah', 172000, 40, -112),
('SALTA', 'Salta', 'RA', 'Salta', 374000, -25, -65),
('SALTIL', 'Saltillo', 'MEX', 'Coahuila', 441000, 25, -101),
('SALVAD', 'Salvador', 'BR', 'Bahia', 2200000, -13, -38),
('SALZBU', 'Salzburg', 'A', 'Salzburg', 145345, 47, 13),
('SAN_AN', 'San Antonio', 'USA', 'Texas', 992000, 29, -98),
('SAN_DI', 'San Diego', 'USA', 'California', 1180000, 32, -117),
('SAN_FE', 'San Fernando', 'RA', 'Catamarca', 141000, -28, -66),
('SAN_FR', 'San Francisco', 'USA', 'California', 752000, 37, -123),
('SAN_JO', 'San Jose', 'CR', 'Costa Rica', 321000, 10, -84),
('SAN_JU', 'San Juan', 'RA', 'San Juan', 119000, -31, -68),
('SANLUI', 'San Luis', 'RA', 'San Luis', 121000, -33, -66),
('SAN_LU', 'San Luis Potosi', 'MEX', 'San Luis Potosi', 526000, 22, -101),
('SAN_MA', 'San Marino', 'RSM', 'San Marino', 2300, 43, 12),
('SAN_MI', 'San Miguel de Tucuman', 'RA', 'Tucuman', 473000, -27, -65),
('SAN_SA', 'San Salvador', 'ES', 'El Salvador', 611000, 13, -89),
('SANSAJ', 'San Salvador de Jujuy', 'RA', 'Jujuy', 170000, -24, -65),
('SANA', 'Sana', 'JEM', NULL, 427185, 15, 44),
('SANTAF', 'Santa Fe', 'USA', 'New Mexico', 62500, 35, -106),
('SANTA_', 'Santa Rosa', 'RA', 'La Pampa', 75100, -36, -64),
('SANTIA', 'Santiago', 'RCH', NULL, 5100000, -33, -71),
('SANTIE', 'Santiago del Estero', 'RA', 'Santiago del Estero', 202000, -28, -64),
('SANTO_', 'Santo Domingo', 'DOM', 'Dominikanische Republik', 21, 18, -70),
('SAO_LU', 'Sao Luis', 'BR', 'Maranhao', 738000, -2, -44),
('SAO_PA', 'Sao Paulo', 'BR', 'Sao Paulo', 10099100, -23, -47),
('SAO_TO', 'Sao Tome', 'SAO', 'Sao Tome u Principe', NULL, NULL, NULL),
('SAPPOR', 'Sapporo', 'J', NULL, 1800000, 43, 141),
('SARAJE', 'Sarajevo', 'BIH', NULL, 360000, 44, 18),
('SASKAT', 'Saskatoon', 'CDN', 'Saskatchewan', 186000, 52, -107),
('SCHIRA', 'Schiraz', 'IR', 'Fars', 425813, 29, 52),
('SCHWED', 'Schwedt', 'D', 'Brandenburg', 46030, 53, 14),
('SCHWEI', 'Schweinfurt', 'D', 'Bayern', 55747, 50, 10),
('SCHWER', 'Schwerin', 'D', 'Mecklenburg-Vorpommern', 100628, 54, 11),
('SEOUL', 'Seoul', 'ROK', NULL, 10700000, 37, 127),
('SHANGH', 'Shanghai', 'VRC', 'Jiangsu', 14200000, 31, 121),
('SHENYA', 'Shenyang', 'VRC', 'Liaoning', 3900000, 42, 123),
('SHIJIA', 'Shijiazhuang', 'VRC', 'Hebei', 1300000, 38, 114),
('SHILLO', 'Shillong', 'IND', 'Meghalaya', 222000, 25, 91),
('SIMLA', 'Simla', 'IND', 'Himachal Pradesh', 70000, 31, 77),
('SHKODE', 'Shkodra', 'AL', 'Shkodra', 83700, 42, 19),
('SIEGMA', 'Sigmaringen', 'D', 'Baden-Wuerttemberg', 16580, 48, 9),
('SILVAS', 'Silvassa', 'IND', 'Dadra & Nagar Haveli', 6900, 20, 73),
('SINGAP', 'Singapur', 'SGP', NULL, 2600000, 1, 103),
('SKIEN', 'Skien', 'N', 'Telemark', 47010, 59, 9),
('SKOPJE', 'Skopje', 'MK', NULL, 448000, 42, 21),
('SOFIA', 'Sofia', 'BG', NULL, 1100000, 42, 23),
('SPRING', 'Springfield', 'USA', 'Illinois', 106000, 39, -90),
('SRINAG', 'Srinagar', 'IND', 'Jammu und Kashmir', 595000, 34, 74),
('STHELI', 'St. Helier', 'GB', 'Jersey', 27100, 49, -2),
('STJOHN', 'St. John''s', 'CDN', 'Neufoundland', 143390, 47, -53),
('STLOUI', 'St. Louis', 'USA', 'Missouri', 368000, 38, -90),
('STPAUL', 'St. Paul', 'USA', 'Minnesota', 262000, 45, -93),
('STPETE', 'St. Peter Port', 'GB', 'Guernsey', 16300, 49, -2),
('STPOEL', 'St.Pölten', 'A', 'Niederoesterr.', 50026, 48, 15),
('STAIS', 'Sta. Isabel', 'RGE', 'Aequatorialguinea', NULL, 3, 8),
('STARNB', 'Starnberg', 'D', 'Bayern', 21235, 48, 11),
('STAVAN', 'Stavanger', 'N', 'Rogaland', 95089, 59, 5),
('STEINK', 'Steinkjer', 'N', 'Nord-Trondelag', 20480, 64, 11),
('STOCKH', 'Stockholm', 'S', 'Stockholms laen', 718000, 59, 18),
('STRALS', 'Stralsund', 'D', 'Mecklenburg-Vorpommern', 64385, 54, 13),
('STRASB', 'Strasbourg', 'F', 'Alsace', 248000, 48, 7),
('STRAUB', 'Straubing', 'D', 'Bayern', 44482, 49, 13),
('STUTTG', 'Stuttgart', 'D', 'Baden-Wuerttemberg', 585540, 49, 9),
('SUCRE', 'Sucre', 'BOL', NULL, 145000, -19, -65),
('SURABA', 'Surabaja', 'RI', 'Java', 2027913, -7, 112),
('SUVA', 'Suva', 'FIJI', NULL, 80000, -18, 178),
('SVOLVA', 'Svolvaer', 'N', 'Nordland', 4500, 68, 14),
('SYDNEY', 'Sydney', 'AUS', 'Neu-Sued-Wales', 3700000, -34, 151),
('TAEBRI', 'Taebriz', 'IR', 'Ost-Aserbeidschan', 597976, 38, 46),
('TAIPEH', 'Taipeh', 'ROC', NULL, 2600000, 25, 121),
('TAIYUA', 'Taiyuan', 'VRC', 'Shanxi', 1680000, 38, 112),
('TALLAH', 'Tallahassee', 'USA', 'Florida', 137000, 30, -84),
('TALLIN', 'Tallinn', 'EST', NULL, 492000, 59, 25),
('TAMPER', 'Tampere', 'SF', 'Haeme', 186000, 61, 23),
('TANANA', 'Tananarive', 'RM', NULL, 1500000, -19, 47),
('TASCHK', 'Taschkent', 'RUS', NULL, 2100000, 41, 69),
('TBILIS', 'Tbilissi', 'GE', NULL, 1280000, 41, 44),
('TEGUCI', 'Tegucigalpa', 'HON', NULL, 814000, 15, -87),
('TEHERA', 'Teheran', 'IR', 'Teheran', 6800000, 35, 51),
('TEPIC', 'Tepic', 'MEX', 'Nayarit', 238000, 21, -105),
('TERESI', 'Teresina', 'BR', 'Piaui', 637000, -5, -43),
('THIMBU', 'Thimbu', 'BHU', NULL, 20000, NULL, NULL),
('THOHOY', 'Thohoyandou', 'V', NULL, 2166, NULL, NULL),
('THORSH', 'Thorshavn', 'DK', 'Faroeer', 15000, 62, -7),
('TIRANA', 'Tirana', 'AL', 'Tirana', 251000, 46, 11),
('TLAXCA', 'Tlaxcala de Xincotencatl', 'MEX', 'Tlaxcala', 116800, 19, -98),
('TOENSB', 'Toensberg', 'N', 'Vestfold', 8984, 59, 10),
('TOKYO', 'Tokyo', 'J', NULL, 11800000, 35, 139),
('TOLUCA', 'Toluca de Lerdo', 'MEX', 'Mexico', 136100, 19, -99),
('TOPEKA', 'Topeka', 'USA', 'Kansas', 121000, 39, -95),
('TORGAU', 'Torgau', 'D', 'Sachsen', 20046, 51, 13),
('TORONT', 'Toronto', 'CDN', 'Ontario', 635000, 43, -80),
('TOULOU', 'Toulouse', 'F', 'Midi-Pyrenes', 366000, 43, 1),
('TRENTO', 'Trenton', 'USA', 'New Jersey', 84400, 40, -75),
('TRIENT', 'Trient', 'I', 'Tretino-Suedti.', 105000, 46, 11),
('TRIER', 'Trier', 'D', 'Rheinland-Pfalz', 99750, 50, 7),
('TRIEST', 'Triest', 'I', 'Friaul-Jul.Ven.', 220000, 45, 13),
('TRIPOL', 'Tripolis', 'LAR', NULL, 591000, 37, 22),
('TRIVAN', 'Trivandrum', 'IND', 'Kerala', 520000, 8, 77),
('TROMSO', 'Tromsoe', 'N', 'Troms', 48109, 69, 19),
('TRONDH', 'Trondheim', 'N', 'Soer-Trondelag', 134426, 63, 10),
('TUEBIN', 'Tübingen', 'D', 'Baden-Wuerttemberg', 81911, 49, 9),
('TUNIS', 'Tunis', 'TN', NULL, 674000, 36, 11),
('TURIN', 'Turin', 'I', 'Piermont', 917000, 45, 7),
('TURKU', 'Turku', 'SF', 'Turku-Pori', 167000, 60, 22),
('TUXTLA', 'Tuxtla Gutierrez', 'MEX', 'Chiapas', 66851, 16, -93),
('ULAN_B', 'Ulan Bator', 'MON', 'Mongolische Volksrepublik', 627000, 48, 107),
('ULIGA', 'Majuro', 'MAR', 'Dalap-Uliga-Darrit', 40000, 7, 171),
('ULM', 'Ulm', 'D', 'Baden-Wuerttemberg', 116021, 48, 10),
('UMEO', 'Umeo', 'S', 'Vaesterbottens laen', 85698, 63, 20),
('UMTATA', 'Umtata', 'X', 'Ostkap', 50000, -31, 28),
('UPPSAL', 'Uppsala', 'S', 'Uppsala laen', 186000, 59, 17),
('URUMIY', 'Urumiyeh', 'IR', 'West-Aserbeidschan', 164419, 37, 45),
('URUMQI', 'Urumqi', 'VRC', 'Xinjiang', NULL, 44, 88),
('USHUAI', 'Ushuaia', 'RA', 'Nationales Territorium', 29500, -55, -68),
('VAASA', 'Vaasa', 'SF', 'Vaasa', 447000, 63, 21),
('VADSOE', 'Vadsoe', 'N', 'Finnmark', 5961, 70, 29),
('VAENER', 'Vaenersborg', 'S', 'Aelvsborgs laen', 36500, 58, 12),
('VAESTE', 'Vaesteros', 'S', 'Vaestmanlands laen', 117732, 59, 16),
('VAEXJO', 'Vaexjoe', 'S', 'Kronobergs laen', 73100, 56, 15),
('VALLET', 'Valletta', 'M', 'Malmoehus laen', 9100, 35, 14),
('VALPAR', 'Valparaiso', 'RCH', NULL, 282000, -33, -71),
('VANCOU', 'Vancouver', 'CDN', 'British Columbia', 1800000, 48, -122),
('VATIKA', 'Vatikanstadt', 'SCV', NULL, 392, 41, 12),
('VEIAKU', 'Veiaku', 'TUV', NULL, 2120, NULL, NULL),
('VENEDI', 'Venedig', 'I', 'Venetien', 306000, 45, 12),
('VICTOR', 'Victoria', 'CDN', 'British Columbia', 304000, 48, -123),
('VIEDMA', 'Viedma', 'RA', 'Rio Negro', 40500, -41, -63),
('VIENTI', 'Vientiane', 'LAO', NULL, 532000, 18, 102),
('VILLAH', 'Villahermosa', 'MEX', 'Tabasco', 133200, 18, -93),
('VILNIU', 'Vilnius', 'LT', NULL, 590000, 54, 25),
('VISBY', 'Visby', 'S', 'Gotlands laen', 21000, 57, 18),
('VITORI', 'Vitoria', 'BR', 'Esperito Santo', 267000, -20, -40),
('VLORE', 'Vlora', 'AL', 'Vlora', 76000, 40, 19),
('VOELKL', 'Völklingen', 'D', 'Saarland', 44081, 49, 6),
('WAKRAH', 'Wakrah', 'Q', 'Katar', 23682, NULL, NULL),
('WALDSH', 'Waldshut-Tiengen', 'D', 'Baden-Wuerttemberg', 22211, 47, 8),
('WAREN', 'Waren', 'D', 'Mecklenburg-Vorpommern', 22281, 54, 13),
('WAREND', 'Warendorf', 'D', 'Nordrhein-Westfalen', 37393, 52, 8),
('WARSCH', 'Warschau', 'PL', NULL, 1600000, 52, 21),
('WASHIN', 'Washington', 'USA', 'District of Columbia', 543000, 38, -77),
('WEISEN', 'Weißenfels', 'D', 'Sachsen-Anhalt', 29000, 51, 12),
('WELLIN', 'Wellington', 'NZ', NULL, 335000, -41, 174),
('WHITEH', 'Whitehorse', 'CDN', 'Yukon Territory', 21100, 60, -135),
('WIEN', 'Wien', 'A', 'Wien', 1610000, 48, 16),
('WIESBA', 'Wiesbaden', 'D', 'Hessen', 267669, 50, 8),
('WILHEL', 'Wilhelmshaven', 'D', 'Niedersachsen', 82700, 54, 8),
('WILLIA', 'Williamsburg', 'USA', 'Virginia', 9870, 37, -77),
('WINDHU', 'Windhuk', 'SWA', NULL, 159000, -22, 17),
('WINNIP', 'Winnipeg', 'CDN', 'Manitoba', 667000, 49, -97),
('WLADIW', 'Wladiwostok', 'RUS', 'Fernost', 632000, 43, 132),
('WORMS', 'Worms', 'D', 'Rheinland-Pfalz', 80535, 49, 8),
('WUERZB', 'Würzburg', 'D', 'Bayern', 126970, 50, 10),
('WUHAN', 'Wuhan', 'VRC', 'Hubei', 3900000, 30, 114),
('WURZEN', 'Wurzen', 'D', 'Sachsen', 16969, 51, 13),
('XIAN', 'Xian', 'VRC', 'Shaanxi', 1600000, 34, 109),
('XINING', 'Xining', 'VRC', 'Qinghai', 552000, 37, 102),
('YAREN', 'Yaren', 'NAU', NULL, NULL, NULL, NULL),
('YELLOW', 'Yellowknife', 'CDN', 'Northwest Territories', 13700, 62, -114),
('YINCHU', 'Yinchuan', 'VRC', 'Ningxia', 357000, 38, 106),
('ZACATE', 'Zacatecas', 'MEX', 'Zacatecas', 50251, 22, -102),
('ZAGREB', 'Zagreb', 'HR', NULL, 707000, 46, 16),
('ZHENGZ', 'Zhengzhou', 'VRC', 'Henan', 1050000, 34, 114),
('ZITTAU', 'Zittau', 'D', 'Sachsen', 29373, 51, 15),
('BISTRI', 'Bistrita', 'RO', NULL, NULL, NULL, NULL),
('BOTOSA', 'Botosani', 'RO', NULL, NULL, NULL, NULL),
('CALARA', 'Calarasi', 'RO', NULL, NULL, NULL, NULL),
('RESITA', 'Resita', 'RO', NULL, NULL, NULL, NULL),
('TIRGOV', 'Tirgoviste', 'RO', NULL, NULL, NULL, NULL),
('GIURGI', 'Giurgiu', 'RO', NULL, NULL, NULL, NULL),
('DEVA', 'Deva', 'RO', NULL, NULL, NULL, NULL),
('SLOBOZ', 'Slobozia', 'RO', NULL, NULL, NULL, NULL),
('SLATIN', 'Slatina', 'RO', NULL, NULL, NULL, NULL),
('PLOIES', 'Ploiesti', 'RO', NULL, NULL, NULL, NULL),
('ZALAU', 'Zalau', 'RO', NULL, NULL, NULL, NULL),
('SUCEAV', 'Suceava', 'RO', NULL, NULL, NULL, NULL),
('TULCEA', 'Tulcea', 'RO', NULL, NULL, NULL, NULL),
('VASLUI', 'Vaslui', 'RO', NULL, NULL, NULL, NULL),
('FOCSAN', 'Focsani', 'RO', NULL, NULL, NULL, NULL),
('ARAD1', 'Arad', 'RO', NULL, 191000, NULL, NULL),
('BACAU1', 'Bacau', 'RO', NULL, 193000, NULL, NULL),
('BRAILA', 'Braila', 'RO', NULL, 243000, NULL, NULL),
('BRASOV', 'Brasov', 'RO', NULL, 353000, NULL, NULL),
('BUZAU1', 'Buzau', 'RO', NULL, 145000, NULL, NULL),
('CONST3', 'Constanta', 'RO', NULL, 316000, NULL, NULL),
('GALATI', 'Galati', 'RO', NULL, 307000, 45, 28),
('IASI3', 'Iasi', 'RO', NULL, 330000, NULL, NULL),
('SATUM1', 'Satu Mare', 'RO', NULL, 137000, NULL, NULL),
('SIBIU1', 'Sibiu', 'RO', NULL, 184000, NULL, NULL),
('BUCHAR', 'Bucharest', 'RO', NULL, 2037000, 44, 26),
('PITEST', 'Pitesti', 'RO', NULL, 162000, NULL, NULL),
('ORADEA', 'Oradea', 'RO', NULL, 225000, NULL, NULL),
('CLUJN3', 'Cluj Napoca', 'RO', NULL, 318000, NULL, NULL),
('CRAIOV', 'Craiova', 'RO', NULL, 300000, 44, 24),
('BAIAM1', 'Baia Mare', 'RO', NULL, 150000, NULL, NULL),
('TIRGU1', 'Tirgu Mures', 'RO', NULL, 165000, NULL, NULL),
('TIMISO', 'Timisoara', 'RO', NULL, 333000, NULL, NULL),
('ALBAI', 'Alba Iulia', 'RO', NULL, NULL, NULL, NULL),
('SFINTU', 'Sfintu Gheorghe', 'RO', NULL, NULL, NULL, NULL),
('TIRGU', 'Tirgu Jiu', 'RO', NULL, NULL, NULL, NULL),
('MIERCU', 'Miercurea Ciuc', 'RO', NULL, NULL, NULL, NULL),
('DROBET', 'Drobeta Turnu Severin', 'RO', NULL, NULL, NULL, NULL),
('PIATRA', 'Piatra Neamt', 'RO', NULL, NULL, NULL, NULL),
('RIMNIC', 'Rimnicu Vilcea', 'RO', NULL, NULL, NULL, NULL),
('RUSSE', 'Russe', 'BG', NULL, 169000, 44, 26),
('VOUKOV', 'Vukovar', 'HR', NULL, 32000, 45, 19),
('GIURG1', 'Giurgiulesti', 'MD', NULL, NULL, NULL, NULL),
('NIS', 'Nis', 'YU', NULL, 237000, NULL, NULL),
('NOVISA', 'Novi Sad', 'YU', NULL, 299000, 45, 20),
('HEIDEL', 'Heidelberg', 'D', NULL, 144600, 49, 8),
('METZ1', 'Metz', 'F', 'Moselle', 119594, 49, 6),
('SARGEM', 'Sarreguemines ', 'F', 'Moselle', 23202, 49, 7),
('DHAKA', 'Dhaka', 'BD', NULL, 6001000, 23, 90),
('ASGABA', 'Asgabat', 'TM', NULL, 798000, NULL, NULL),
('ZURICH', 'Zürich', 'CH', 'Zürich', 367000, 47, 9),
('BASEL', 'Basel', 'CH', 'Basel', 166000, 48, 8),
('LAUSAN', 'Lausanne', 'CH', 'Waadt', 129200, 47, 7),
('ROTTER', 'Rotterdam', 'NL', 'Südholland', 585000, 52, 4),
('DENHAA', 'Den Haag', 'NL', NULL, 475000, 52, 4),
('ARNHEI', 'Arnheim', 'NL', 'Gelderland', 142200, 52, 6),
('UTRECH', 'Utrecht', 'NL', 'Utrecht', 283363, 52, 5),
('BRNO', 'Brno', 'CZ', NULL, 367729, 49, 17),
('OSTRAV', 'Ostrava', 'CZ', NULL, 317000, NULL, NULL),
('PLZEN', 'Plzen', 'CZ', NULL, 165000, 50, 13),
('OLOMOU', 'Olomouc', 'CZ', NULL, 102600, NULL, NULL),
('HRADEC', 'Hradec Kralove', 'CZ', NULL, 95200, NULL, NULL),
('PARDUB', 'Pardubice', 'CZ', NULL, 88120, NULL, NULL),
('HANNMU', 'Hann. Münden', 'D', 'Niedersachsen', 25000, 51, 9),
('EISENA', 'Eisenach', 'D', 'Thüringen', 43626, 51, 10),
('OFFENB', 'Offenbach am Main', 'D', 'Hessen', 117000, 51, 8),
('OPOLE', 'Opole', 'PL', 'Oberschlesien', 128864, 51, 18),
('BRESLA', 'Wroclaw (Breslau)', 'PL', 'Niederschlesien', 635200, NULL, NULL),
('SZCZEC', 'Szczecin (Stettin)', 'PL', 'Westpommern', NULL, NULL, NULL),
('LODZ', 'Lodz', 'PL', NULL, 760251, 52, 19),
('DANZIG', 'Gdansk (Danzig)', 'PL', NULL, 460014, NULL, NULL),
('KRAKOW', 'Krakow (Krakau)', 'PL', 'Kleinpolen', 756336, NULL, NULL),
('POZNAN', 'Poznan (Posen)', 'PL', 'Großpolen', 564035, NULL, NULL),
('BYDGOS', 'Bydgoszcz', 'PL', 'Pommern', NULL, NULL, NULL),
('KATOWI', 'Katowice', 'PL', 'Schlesien', NULL, NULL, NULL),
('LUZERN', 'Luzern', 'CH', 'Luzern', 200200, 47, 8),
('KOSICE', 'Kosice', 'SK', NULL, 235000, NULL, NULL),
('PRESOV', 'Presov', 'SK', NULL, NULL, NULL, NULL),
('MARIBO', 'Maribor', 'SLO', NULL, 111000, NULL, NULL),
('THESSA', 'Thessaloniki', 'GR', 'Zentralmakedonien', 348920, 41, 23),
('PIRAEU', 'Piräus', 'GR', 'Attika', 170715, NULL, NULL),
('PATRAS', 'Patras', 'GR', NULL, 164000, 38, 22),
('IRAKLI', 'Iraklio', 'GR', 'Kreta', 140357, NULL, NULL),
('PERIST', 'Peristeri', 'GR', 'Attika', 137472, NULL, NULL),
('LARISA', 'Larisa', 'GR', 'Thessalien', 130946, NULL, NULL),
('CORKIR', 'Cork', 'IRL', 'Munster', 119143, 52, -8),
('GALWAY', 'Galway', 'IRL', 'Galway', 71983, NULL, NULL),
('TALLAG', 'Tallaght', 'IRL', 'Dublin', 64282, NULL, NULL),
('PORTOP', 'Porto', 'P', 'Norte', 246264, NULL, NULL),
('AMADOR', 'Amadora', 'P', 'Lissabon', 179486, NULL, NULL),
('BRAGA', 'Braga', 'P', 'Norte', 123367, NULL, NULL),
('SETUBA', 'Setubal', 'P', 'Lissabon', 118056, NULL, NULL),
('COIMBR', 'Coimbra', 'P', 'Centro', 107506, NULL, NULL),
('TARTU', 'Tartu', 'EST', NULL, 101740, 58, 27),
('NARVA', 'Narva', 'EST', NULL, 66936, 59, 28),
('DAUGAV', 'Daugavpils', 'LV', NULL, 111564, NULL, NULL),
('LIEPAJ', 'Liepaja (Libau)', 'LV', NULL, 85260, NULL, NULL),
('KAUNAS', 'Kaunas', 'LT', NULL, 360637, NULL, NULL),
('KLAIPE', 'Klaipeda (Memel)', 'LT', NULL, 187316, NULL, NULL),
('SIAULI', 'Siauliai', 'LT', NULL, 127000, NULL, NULL),
('PANEVE', 'Panevezys', 'LT', NULL, 115000, 56, 24),
('DEBREC', 'Debrecen', 'H', NULL, 204297, NULL, NULL),
('MISKOL', 'Miskolc', 'H', NULL, 175000, NULL, NULL),
('SZEGED', 'Szeged', 'H', NULL, 162000, NULL, NULL),
('PECS', 'Pecs', 'H', NULL, 156567, NULL, NULL),
('GYOR', 'Gyor', 'H', NULL, 127594, NULL, NULL),
('HOMEL', 'Homel', 'BY', NULL, 479000, NULL, NULL),
('MAHILJ', 'Mahiljou', 'BY', NULL, 367000, NULL, NULL),
('WIZEBS', 'Wizebsk', 'BY', NULL, 342000, NULL, NULL),
('HRODNA', 'Hrodna', 'BY', NULL, 323000, NULL, NULL),
('BREST', 'Brest', 'BY', NULL, 306090, 52, 24),
('BABRUS', 'Babrujsk', 'BY', NULL, 220000, NULL, NULL),
('BARANA', 'Baranawitschi', 'BY', NULL, 169522, NULL, NULL),
('BARYSS', 'Baryssau', 'BY', NULL, NULL, NULL, NULL),
('PINSK', 'Pinsk', 'BY', NULL, NULL, NULL, NULL),
('ORSCHA', 'Orscha', 'BY', NULL, 125000, 54, 30),
('CHARKI', 'Charkiw', 'UA', NULL, 1463174, NULL, NULL),
('DNIPRO', 'Dnipropetrowsk', 'UA', NULL, 1047347, NULL, NULL),
('ODESSA', 'Odessa', 'UA', NULL, 1002048, NULL, NULL),
('DONEZK', 'Donezk', 'UA', NULL, 993519, NULL, NULL),
('SAPORI', 'Saporischschja', 'UA', NULL, 794687, NULL, NULL),
('LWIW', 'Lwiw', 'UA', NULL, 734884, NULL, NULL),
('KRYWYJ', 'Krywyj Rih', 'UA', NULL, 692000, NULL, NULL),
('MYKOLA', 'Mykolajiw', 'UA', NULL, 508000, NULL, NULL),
('MARIUP', 'Mariupol', 'UA', NULL, 479000, NULL, NULL),
('BANJAL', 'Banja Luka', 'BIH', NULL, 173748, 45, 17),
('TUZLA', 'Tuzla', 'BIH', NULL, 88000, 45, 19),
('ZENICA', 'Zenica', 'BIH', NULL, 85649, 44, 18),
('MOSTAR', 'Mostar', 'BIH', NULL, 64301, 43, 18),
('PLOWDI', 'Plowdiw', 'BG', NULL, 341473, 42, 25),
('WARNA', 'Warna', 'BG', NULL, 311796, 43, 28),
('BURGAS', 'Burgas', 'BG', NULL, 189245, 43, 27),
('STARAS', 'Stara Sagora', 'BG', NULL, 141000, 42, 26),
('BIRMHA', 'Birmingham', 'GB', 'England', 989141, 52, -2),
('GLASGO', 'Glasgow', 'GB', 'Schottland', 604355, 56, -4),
('LIVERP', 'Liverpool', 'GB', 'England', 468011, 53, -3),
('LEEDS', 'Leeds', 'GB', 'England', 460459, 54, -2),
('SHEFFE', 'Sheffield', 'GB', 'England', 449971, 53, -1),
('LEICES', 'Leicester', 'GB', 'England', 343019, 53, -1),
('BRISTO', 'Bristol', 'GB', 'England', 435028, 51, -3),
('MANCHE', 'Manchester', 'GB', 'England', 395323, 53, -2),
('COVENT', 'Coventry', 'GB', 'England', 310200, 52, -1),
('OXFORD', 'Oxford', 'GB', 'England', 160587, 52, -1),
('KINGHU', 'Kingston upon Hull', 'GB', 'England', 301984, NULL, NULL),
('BRADFO', 'Bradford', 'GB', 'England', 301499, NULL, NULL),
('STOKET', 'Stoke-on-Trent', 'GB', 'England', 260336, 53, -2),
('WOLVER', 'Wolverhampton', 'GB', 'England', 252814, NULL, NULL),
('SOUHAM', 'Southampton', 'GB', 'England', 252129, 51, -1),
('READIN', 'Reading', 'GB', 'England', 249000, NULL, NULL),
('PLYMTH', 'Plymouth', 'GB', 'England', 248402, 50, -8),
('NOTTIN', 'Nottingham', 'GB', 'England', 244411, 53, -2),
('DERBY', 'Derby', 'GB', 'England', 237341, 53, -1),
('PRTSMT', 'Portsmouth', 'GB', 'England', 197471, 51, -1),
('ABEDEE', 'Aberdeen', 'GB', 'Schottland', 184334, 57, 2),
('STMORI', 'St. Moritz', 'CH', 'Graubünden', 5119, 46, 10),
('WOLFSB', 'Wolfsburg', 'D', 'Niedersachsen', 120493, 52, 10),
('VERDEN', 'Verden', 'D', 'Niedersachsen', 26973, 53, 9),
('KANDAH', 'Kandahar', 'AF', NULL, 323900, 31, 65),
('MASARE', 'Masar-e Scharif', 'AF', NULL, 250000, 36, 67),
('GRDJUN', 'Grand Junction', 'USA', 'Colorado', 45300, 39, -109),
('LHAVAS', 'Lake Havasu City', 'USA', 'Arizona', 55300, NULL, NULL),
('YUMA', 'Yuma', 'USA', 'Arizona', 84680, 33, -115),
('SLRCOL', 'San Luis Rio Colorado', 'MEX', 'Sonora', 145000, NULL, NULL);
INSERT INTO `ort` (`ONR`, `Name`, `LNR`, `Landesteil`, `Einwohner`, `Breite`, `Laenge`) VALUES
('BOUCIT', 'Boulder City', 'USA', 'Nevada', 15000, NULL, NULL),
('PORTLA', 'Portland', 'USA', 'Oregon', 562000, NULL, NULL),
('VCOUVE', 'Vancouver', 'USA', 'Washington', 157490, NULL, NULL),
('FREDRI', 'Fredrikstad', 'N', 'Fylke', 71900, NULL, NULL),
('TAMWOR', 'Tamworth', 'GB', 'Staffordshire', 74000, 53, -2),
('GRENOB', 'Grenoble', 'F', 'Isere', 158000, 45, 6),
('SARAGO', 'Saragossa', 'E', 'Aragonien', 640000, 42, -1),
('LOGRON', 'Logrono', 'E', 'Rioja', 147180, 42, -2),
('LLEIDA', 'Lleida', 'E', 'Katalonien', 125600, 42, 1),
('ALBUQU', 'Albuquerque', 'USA', 'New Mexico', 484246, 35, -107),
('ELPASO', 'El Paso', 'USA', 'Texas', 624365, 32, -106),
('CIUJUR', 'Ciudad Juarez', 'MEX', 'Chihuahua', 1301452, 32, -106);


INSERT INTO `Sprache` (`SNR`, `Name`) VALUES
('AFG', 'Afghanisch'),
('AFR', 'Afrikaans'),
('ALB', 'Albanisch'),
('AMH', 'Amharisch'),
('ARA', 'Arabisch'),
('ARM', 'Armenisch'),
('AZE', 'Azeri'),
('BAL', 'Baloch'),
('BAM', 'Bambara'),
('BAO', 'Balochi'),
('BAS', 'Baskisch'),
('BRA', 'Brahui'),
('BUL', 'Bulgarisch'),
('BUR', 'Burmesisch'),
('BUS', 'Burushaski'),
('BYR', 'Weißrussisch'),
('CAT', 'Katalanisch'),
('DNK', 'Dänisch'),
('DUT', 'Niederländisch'),
('ENG', 'Englisch'),
('EST', 'Estnisch'),
('FIN', 'Finnisch'),
('FRE', 'Französisch'),
('GAL', 'Galicisch'),
('GEO', 'Georgisch'),
('GER', 'Deutsch'),
('GRE', 'Griechisch'),
('GUA', 'Guarani'),
('HBR', 'Hebräisch'),
('HER', 'Herero'),
('HIK', 'Hindko'),
('HIN', 'Hindi'),
('HUN', 'Ungarisch'),
('ICE', 'Isländisch'),
('IND', 'Indisch'),
('IRI', 'Irisch'),
('ITA', 'Italienisch'),
('JAP', 'Japanisch'),
('KAZ', 'Kazak'),
('KHA', 'Khalkha Mongolisch'),
('KIR', 'Kirgisisch');
('KRU', 'Kirundi');
('KOR', 'Koreanisch'),
('KUR', 'Kurdisch'),
('LAN', 'Oshivambo'),
('LAP', 'Russisch (Lappen)'),
('LAT', 'Latein'),
('LET', 'Lettisch'),
('LIT', 'Litauisch'),
('LUR', 'Luri'),
('LUX', 'Luxemburgisch'),
('MAC', 'Mazedonisch'),
('MAL', 'Maltesisch'),
('MAN', 'Mandarin (Hochchinesisch)'),
('MAO', 'Maori'),
('NAM', 'Nama'),
('NEP', 'Nepali'),
('NOR', 'Norwegisch'),
('PAS', 'Pashtu'),
('PER', 'Persisch'),
('POL', 'Polnisch'),
('POR', 'Portugiesisch'),
('PUN', 'Punjabi'),
('ROA', 'Romani'),
('ROM', 'Rätoromanisch'),
('RUM', 'Rumänisch'),
('RUS', 'Russisch'),
('SER', 'Serbokroatisch'),
('SES', 'Sesotho'),
('SIH', 'Sinhala'),
('SIN', 'Sindhi'),
('SIR', 'Siraiki'),
('SLO', 'Slovenisch'),
('SLV', 'Slovakisch'),
('SOM', 'Somali'),
('SPA', 'Spanisch'),
('SWA', 'Swahili'),
('SWE', 'Swedisch'),
('TAJ', 'Tajik'),
('TAM', 'Tamil'),
('TSC', 'Tschechisch'),
('TUC', 'Turkic'),
('TUK', 'Türkisch'),
('TUM', 'Turkmenisch'),
('TUR', 'Turkisch'),
('UKR', 'Ukrainisch'),
('URD', 'Urdu'),
('UZB', 'Uzbekisch'),

INSERT INTO `gesprochen` (`SNR`, `LNR`, `Anteil`) VALUES
('GER', 'A', 100),
('ENG', 'AC', 100),
('TUC', 'AF', 11),
('PAS', 'AF', 35),
('AFG', 'AF', 50),
('ENG', 'AG', 100),
('ALB', 'AL', 95),
('RUS', 'AM', 2),
('ARM', 'AM', 96),
('CAT', 'AN', 45),
('SPA', 'AN', 35),
('FRE', 'AN', 20),
('POR', 'AO', 100),
('ENG', 'AUS', 79),
('RUS', 'AZ', 3),
('ARM', 'AZ', 2),
('AZE', 'AZ', 89),
('FRE', 'B', 32),
('GER', 'B', 1),
('DUT', 'B', 56),
('ARA', 'BA', 100),
('ENG', 'BF', 100),
('BUL', 'BG', 100),
('ENG', 'BH', 75),
('SPA', 'BH', 15),
('SER', 'BIH', 99),
('POR', 'BR', 97),
('SPA', 'BOL', 60),
('KRU', 'BU', 100),
('BUR', 'BUR', 100),
('BYR', 'BY', 30),
('RUS', 'BY', 70),
('SPA', 'C', 100),
('ENG', 'CDN', 57),
('FRE', 'CDN', 28),
('FRE', 'CH', 18),
('GER', 'CH', 65),
('ITA', 'CH', 12),
('ROM', 'CH', 1),
('FRE', 'CI', 100),
('TAM', 'CL', 18),
('SIH', 'CL', 74),
('SPA', 'CO', 100),
('SPA', 'CR', NULL),
('TSC', 'CZ', 100),
('GER', 'D', 100),
('ARA', 'DARS', NULL),
('DNK', 'DK', 100),
('SPA', 'DOM', 100),
('SPA', 'E', 70),
('CAT', 'E', 17),
('GAL', 'E', 7),
('BAS', 'E', 2),
('ARA', 'EAS', NULL),
('ENG', 'EAS', NULL),
('ENG', 'EAU', NULL),
('SWA', 'EAU', NULL),
('SWA', 'EAT', NULL),
('SPA', 'EC', NULL),
('ARA', 'ET', NULL),
('AMH', 'ETH', NULL),
('ENG', 'GH', NULL),
('ENG', 'EAK', NULL),
('SWA', 'EAK', NULL),
('SPA', 'ES', NULL),
('EST', 'EST', 80),
('FRE', 'F', 100),
('GER', 'FL', 100),
('FRE', 'GAB', NULL),
('ENG', 'GB', 95),
('SPA', 'GCA', 60),
('IND', 'GCA', 40),
('RUS', 'GE', 9),
('ARM', 'GE', 7),
('AZE', 'GE', 6),
('GEO', 'GE', 71),
('GRE', 'GR', 98),
('ENG', 'GUY', NULL),
('HUN', 'H', 98),
('SPA', 'HON', NULL),
('SER', 'HR', 96),
('ITA', 'I', 100),
('ARA', 'IL', NULL),
('HBR', 'IL', NULL),
('HIN', 'IND', 30),
('TUR', 'IR', 1),
('KUR', 'IR', 9),
('BAL', 'IR', 1),
('ARA', 'IR', 1),
('LUR', 'IR', 2),
('PER', 'IR', 58),
('TUK', 'IR', 26),
('IRI', 'IRL', 3),
('ENG', 'IRL', 95),
('ARA', 'IRQ', 80),
('KUR', 'IRQ', 15),
('ICE', 'IS', 100),
('JAP', 'J', 100),
('ARA', 'JEM', 100),
('ARA', 'JOR', 100),
('KAZ', 'KAS', 40),
('KIR', 'KGS', 100),
('FRE', 'KOM', 100),
('ARA', 'KSA', 100),
('ARA', 'KT', 100),
('LUX', 'L', 70),
('GER', 'L', 20),
('FRE', 'L', 10),
('SES', 'LS', 99),
('ENG', 'LB', 20),
('ARA', 'LAR', 100),
('LIT', 'LT', 80),
('RUS', 'LT', 10),
('POL', 'LT', 10),
('LET', 'LV', 58),
('RUS', 'LV', 37),
('ENG', 'M', NULL),
('MAL', 'M', NULL),
('ARA', 'MA', 100),
('ENG', 'MAR', 100),
('FRE', 'MC', NULL),
('SPA', 'MEX', 100),
('ALB', 'MK', 21),
('MAC', 'MK', 70),
('TUR', 'MK', 3),
('SER', 'MK', 3),
('KHA', 'MON', 90),
('POR', 'MOS', 100),
('ENG', 'MS', NULL),
('NOR', 'N', 100),
('NEP', 'NEP', 100),
('SPA', 'NIC', 100),
('DUT', 'NL', 100),
('ENG', 'NZ', 96),
('MAO', 'NZ', 4),
('ARA', 'OMA', NULL),
('POR', 'P', 100),
('ENG', 'PA', 14),
('ENG', 'PAK', NULL),
('PAS', 'PAK', 8),
('URD', 'PAK', 8),
('PUN', 'PAK', 48),
('SIN', 'PAK', 12),
('BUS', 'PAK', NULL),
('BAO', 'PAK', 3),
('HIK', 'PAK', 2),
('BRA', 'PAK', 1),
('SIR', 'PAK', 10),
('SPA', 'PE', NULL),
('POL', 'PL', 100),
('SPA', 'PY', NULL),
('GUA', 'PY', NULL),
('ARA', 'Q', NULL),
('SPA', 'RA', 90),
('ENG', 'RB', NULL),
('FRE', 'RCA', NULL),
('SWA', 'RCB', NULL),
('FRE', 'RCB', NULL),
('SPA', 'RCH', 100),
('FRE', 'RH', 10),
('ARA', 'RIM', NULL),
('ARA', 'RL', NULL),
('FRE', 'RM', NULL),
('ENG', 'RM', NULL),
('BAM', 'RMM', 80),
('FRE', 'RN', NULL),
('RUM', 'RO', 90),
('HUN', 'RO', 6),
('ROA', 'RO', 2),
('MAN', 'ROC', NULL),
('KOR', 'ROK', 100),
('FRE', 'RPB', NULL),
('ENG', 'RSA', NULL),
('AFR', 'RSA', NULL),
('RUS', 'RUS', 100),
('SPA', 'U', NULL),
('SPA', 'YV', NULL),
('ARA', 'TN', NULL),
('TUK', 'TR', 85),
('KUR', 'TR', 12),
('ITA', 'RSM', 100),
('ENG', 'RWA', NULL),
('FRA', 'RWA', NULL),
('SWE', 'S', 100),
('ENG', 'SAL', NULL),
('LAT', 'SCV', 90),
('FIN', 'SF', 93),
('LAP', 'SF', 1),
('SWE', 'SF', 6),
('SLV', 'SK', 95),
('SLO', 'SLO', 91),
('SER', 'SLO', 7),
('DUT', 'SME', NULL),
('FRE', 'SN', NULL),
('ARA', 'SP', NULL),
('SOM', 'SP', NULL),
('GER', 'SWA', 32),
('ENG', 'SWA', 7),
('HER', 'SWA', NULL),
('NAM', 'SWA', NULL),
('AFR', 'SWA', 60),
('LAN', 'SWA', NULL),
('ARA', 'SYR', NULL),
('FRE', 'TCH', NULL),
('ARA', 'TCH', NULL),
('FRE', 'TG', NULL),
('RUS', 'TM', 12),
('UZB', 'TM', 9),
('TUM', 'TM', 72),
('ENG', 'TON', NULL),
('UKR', 'UA', 73),
('RUS', 'UA', 27),
('ARA', 'UAE', NULL),
('ENG', 'USA', 82),
('SPA', 'USA', 12),
('FRE', 'UV', NULL),
('RUS', 'UZB', 14),
('TAJ', 'UZB', 4),
('UZB', 'UZB', 74),
('MAN', 'VRC', NULL),
('ENG', 'WAG', NULL),
('ENG', 'WAL', NULL),
('ENG', 'WAN', NULL),
('ENG', 'WG', 100),
('ALB', 'YU', 5),
('SER', 'YU', 95),
('ENG', 'Z', NULL),
('FRE', 'ZRE', NULL),
('ENG', 'ZW', NULL),
